<?php
/**
 * Mobile Menu Setting
 *
 * @author LeapIn Corp.
 * @since 1.0.0
 */
$panel = 'leapin_settings';
$section = 'leapin_mobile_menu';
LEAPIN_IDs::initPriority();

$wp_customize->add_section($section_id = $section, array(
    'title' => __('Mobile Menu', 'pjax-blog'),
    'panel' => $panel,
    'description' => '<em>' . __('This section handles the all default settings for your mobile menu mainly used for mobile. Choose the best colors that suites your company and personality.', 'pjax-blog') . '</em>',
    'priority' => 30, // Mixed with top-level-section hierarchy.
));

/**
 * Mobile Menu Button Display
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_mobile_menu_button_display, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'default' => LEAPIN_Theme_Mod::$default_leapin_mobile_menu_button_display,
    'transport' => LEAPIN_IDs::$refresh,
    'sanitize_callback' => 'leapin_sanitize_text',
));

$wp_customize->add_control(LEAPIN_IDs::$leapin_mobile_menu_button_display, array(
    'type' => 'select',
    'label' => __('Show In:', 'pjax-blog'),
    'section' => $section,
    'choices' => LEAPIN_Theme_Mod::$choice_leapin_mobile_menu_button_display,
    'description' => __('Define window width to toggle between desktop menus and a mobile menu.', 'pjax-blog'),
    'priority' => LEAPIN_IDs::getPriority()
));

/**
 * Mobile Menu Button Color
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_mobile_menu_button_color, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'default' => '',
    'transport' => LEAPIN_IDs::$refresh,
    'sanitize_callback' => 'leapin_sanitize_rgba_color'
));

$wp_customize->add_control(new LEAPIN_Customize_Alpha_Color_Control($wp_customize, LEAPIN_IDs::$leapin_mobile_menu_button_color, array(
    'label' => __('Hamburger Menu Color', 'pjax-blog'),
    'section' => $section,
    'settings' => LEAPIN_IDs::$leapin_mobile_menu_button_color,
    'show_opacity' => true,
    'priority' => LEAPIN_IDs::getPriority()
)));

/**
 * Mobile Default State Color
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_mobile_menu_link_color, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'default' => '',
    'transport' => LEAPIN_IDs::$refresh,
    'sanitize_callback' => 'leapin_sanitize_rgba_color'
));
$wp_customize->add_control(new LEAPIN_Customize_Alpha_Color_Control($wp_customize, LEAPIN_IDs::$leapin_mobile_menu_link_color, array(
    'label' => __('Link Color', 'pjax-blog'),
    'section' => $section,
    'settings' => LEAPIN_IDs::$leapin_mobile_menu_link_color,
    'show_opacity' => true,
    'priority' => LEAPIN_IDs::getPriority()
)));

/**
 * Mobile Hover Color
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_mobile_menu_link_color_hover, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'default' => '',
    'transport' => LEAPIN_IDs::$refresh,
    'sanitize_callback' => 'leapin_sanitize_rgba_color'
));
$wp_customize->add_control(new LEAPIN_Customize_Alpha_Color_Control($wp_customize, LEAPIN_IDs::$leapin_mobile_menu_link_color_hover, array(
    'label' => __('Link Hover Color', 'pjax-blog'),
    'section' => $section,
    'settings' => LEAPIN_IDs::$leapin_mobile_menu_link_color_hover,
    'show_opacity' => true,
    'priority' => LEAPIN_IDs::getPriority()
)));

/**
 * Mobile Background Color
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_mobile_menu_bg_color, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'default' => '',
    'transport' => LEAPIN_IDs::$refresh,
    'sanitize_callback' => 'leapin_sanitize_rgba_color'
));
$wp_customize->add_control(new LEAPIN_Customize_Alpha_Color_Control($wp_customize, LEAPIN_IDs::$leapin_mobile_menu_bg_color, array(
    'label' => __('Mobile Menu Background Color', 'pjax-blog'),
    'section' => $section,
    'settings' => LEAPIN_IDs::$leapin_mobile_menu_bg_color,
    'show_opacity' => true,
    'priority' => LEAPIN_IDs::getPriority()
)));

/**
 * Show / Hide
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_mobile_menu_hide_sns_section, array(
    'type' => 'theme_mod', // or 'option'
    'sanitize_callback' => 'leapin_sanitize_mock',
));
$wp_customize->add_control(new LEAPIN_Heading_Larger_Customize_Control($wp_customize, LEAPIN_IDs::$leapin_mobile_menu_hide_sns_section, array(
    'settings' => LEAPIN_IDs::$leapin_mobile_menu_hide_sns_section,
    'label' => __('Show / Hide', 'pjax-blog'),
    'section' => $section,
    'priority' => LEAPIN_IDs::getPriority()
)));

/**
 * Site Name
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_mobile_menu_hide_site_name, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'transport' => LEAPIN_IDs::$refresh,
    'sanitize_callback' => 'leapin_sanitize_checkbox'
));

$wp_customize->add_control(LEAPIN_IDs::$leapin_mobile_menu_hide_site_name, array(
    'settings' => LEAPIN_IDs::$leapin_mobile_menu_hide_site_name,
    'label' => __('Hide Site Name', 'pjax-blog'),
    'section' => $section,
    'type' => 'checkbox',
    'priority' => LEAPIN_IDs::getPriority()
));
/**
 * Site Org Sns
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_mobile_menu_hide_org_sns_btns, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'transport' => LEAPIN_IDs::$refresh,
    'sanitize_callback' => 'leapin_sanitize_checkbox'
));

$wp_customize->add_control(LEAPIN_IDs::$leapin_mobile_menu_hide_org_sns_btns, array(
    'settings' => LEAPIN_IDs::$leapin_mobile_menu_hide_org_sns_btns,
    'label' => __('Hide Publisher SNS Buttons', 'pjax-blog'),
    'section' => $section,
    'type' => 'checkbox',
    'priority' => LEAPIN_IDs::getPriority()
));
/**
 * Site Icon and Desc
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_mobile_menu_hide_icon_desc, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'transport' => LEAPIN_IDs::$refresh,
    'sanitize_callback' => 'leapin_sanitize_checkbox'
));

$wp_customize->add_control(LEAPIN_IDs::$leapin_mobile_menu_hide_icon_desc, array(
    'settings' => LEAPIN_IDs::$leapin_mobile_menu_hide_icon_desc,
    'label' => __('Site Icon and Desc', 'pjax-blog'),
    'section' => $section,
    'type' => 'checkbox',
    'priority' => LEAPIN_IDs::getPriority()
));
/**
 * Site Footer Website
 */
//$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_mobile_menu_hide_web_url, array(
//    'type' => 'theme_mod', // or 'option'
//    'capability' => 'manage_options',
//    'transport' => LEAPIN_IDs::$refresh,
//    'sanitize_callback' => 'leapin_sanitize_checkbox'
//));
//
//$wp_customize->add_control(LEAPIN_IDs::$leapin_mobile_menu_hide_web_url, array(
//    'settings' => LEAPIN_IDs::$leapin_mobile_menu_hide_web_url,
//    'label' => __('Hide SNS Buttons', 'pjax-blog'),
//    'section' => $section,
//    'type' => 'checkbox',
//    'priority' => LEAPIN_IDs::getPriority()
//));
/**
 * Site Footer Address
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_mobile_menu_hide_address, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'transport' => LEAPIN_IDs::$refresh,
    'sanitize_callback' => 'leapin_sanitize_checkbox'
));

$wp_customize->add_control(LEAPIN_IDs::$leapin_mobile_menu_hide_address, array(
    'settings' => LEAPIN_IDs::$leapin_mobile_menu_hide_address,
    'label' => __('Hide Address', 'pjax-blog'),
    'section' => $section,
    'type' => 'checkbox',
    'priority' => LEAPIN_IDs::getPriority()
));
/**
 * Site Footer Phone Num
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_mobile_menu_hide_phone, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'transport' => LEAPIN_IDs::$refresh,
    'sanitize_callback' => 'leapin_sanitize_checkbox'
));

$wp_customize->add_control(LEAPIN_IDs::$leapin_mobile_menu_hide_phone, array(
    'settings' => LEAPIN_IDs::$leapin_mobile_menu_hide_phone,
    'label' => __('Hide Phone Number', 'pjax-blog'),
    'section' => $section,
    'type' => 'checkbox',
    'priority' => LEAPIN_IDs::getPriority()
));
/**
 * Site Email
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_mobile_menu_hide_email, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'transport' => LEAPIN_IDs::$refresh,
    'sanitize_callback' => 'leapin_sanitize_checkbox'
));

$wp_customize->add_control(LEAPIN_IDs::$leapin_mobile_menu_hide_email, array(
    'settings' => LEAPIN_IDs::$leapin_mobile_menu_hide_email,
    'label' => __('Hide Email', 'pjax-blog'),
    'section' => $section,
    'type' => 'checkbox',
    'priority' => LEAPIN_IDs::getPriority()
));
/**
 * hide SNS Buttons
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_mobile_menu_hide_sns_btns, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'transport' => LEAPIN_IDs::$refresh,
    'sanitize_callback' => 'leapin_sanitize_checkbox'
));

$wp_customize->add_control(LEAPIN_IDs::$leapin_mobile_menu_hide_sns_btns, array(
    'settings' => LEAPIN_IDs::$leapin_mobile_menu_hide_sns_btns,
    'label' => __('Hide Share SNS', 'pjax-blog'),
    'section' => $section,
    'type' => 'checkbox',
    'priority' => LEAPIN_IDs::getPriority()
));