<?php

/**
 * Class LEAPIN_Header
 *
 * @author LeapIn Corp.
 * @since 1.0.0
 */
class LEAPIN_Header
{

    private static $inst;

    public function __construct()
    {
        self::getModsInstance();
        require_once('navigation/class-leapin-navigation.php');
        require_once('navigation/class-menu-with-description.php');
        $this->registerNavigationMenus();
        $this->registerActionHooks();

        return $this;
    }

    private static function getModsInstance()
    {
        if (empty(self::$inst)) {
            self::$inst = LEAPIN_Theme_Mod::get_instance();
        }
    }

    /**
     * [registerActionHooks description]
     * @return [type] [description]
     */
    public function registerActionHooks()
    {

        add_action('customize_register', array($this, 'customizer'));
        add_action('after_setup_theme', array($this, 'registerNavigationMenus'));
        add_action('leapin_loc_on_main_header', array($this, 'getSearchIcon'));
        add_action('leapin_loc_end_of_mobile_nav', array($this, 'theMobileMenuFooter'), 10);
        add_action('leapin_loc_top_of_mobile_nav', array($this, 'theMobileMenuHeader'), 10);
        add_filter('leapin_body_class', array($this, 'markInitClsToBody'));

        $this->defineLogoPosition();

        return $this;
    }

    public function theMobileMenuHeader()
    {
        $echo = "";
        $site_name = LEAPIN_Header::leapin_logo('m-menu');
        $site_desc = get_bloginfo('description');
        // site icon
        $site_logo_image = get_site_icon_url(48);
        $org_sns_urls = LEAPIN_General_Settings::get_sns_links();
        $publisher_website_url = self::$inst->get(LEAPIN_IDs::$leapin_publisher_website_url, home_url());

        if (!empty($site_logo_image)) {
            $site_logo_image = "<a href='$publisher_website_url'><img width=\"40\" height=\"40\" src=\"$site_logo_image\" /></a>";
        } else {
            $site_logo_image = "";
        }
        if (leapin_is_mod_visible(LEAPIN_IDs::$leapin_mobile_menu_hide_site_name)) {
            $echo .= $site_name;
        }
        if (leapin_is_mod_visible(LEAPIN_IDs::$leapin_mobile_menu_hide_org_sns_btns)) {
            $echo .= "<div class='mobile-nav__sns-links'>$org_sns_urls</div>";
        }
        if (leapin_is_mod_visible(LEAPIN_IDs::$leapin_mobile_menu_hide_icon_desc)) {
            $echo .= "<div class=\"mobile-nav__author\">";
            $echo .= "$site_logo_image";
            $echo .= "<p>$site_desc</p>";
            $echo .= "</div>";
        }
        echo $echo;
    }

    public function theMobileMenuFooter()
    {
        $inst = self::$inst;
        $echo = "";
        if (leapin_is_mod_visible(LEAPIN_IDs::$leapin_mobile_menu_hide_phone)) {
            $publisher_phone_num = $inst->get(LEAPIN_IDs::$leapin_publisher_phone_num);
            $tel = preg_replace('/([^0-9\\n]|^)/', '', $publisher_phone_num, -1, $count);
            $tel = "tel:$tel";
            $echo .= !empty($publisher_phone_num) ? $this->getFooterTagWrapper($publisher_phone_num, 'fas fa-phone-volume', $tel) : "";
        }
        if (leapin_is_mod_visible(LEAPIN_IDs::$leapin_mobile_menu_hide_email)) {
            $publisher_email = trim($inst->get(LEAPIN_IDs::$leapin_publisher_email));
            $echo .= !empty($publisher_email) ? $this->getFooterTagWrapper($publisher_email, 'fas fa-envelope', "mailto:$publisher_email") : "";
        }
        if (leapin_is_mod_visible(LEAPIN_IDs::$leapin_mobile_menu_hide_address)) {
            $publisher_address = $inst->get(LEAPIN_IDs::$leapin_publisher_address);
            $map_url = esc_url("https://maps.google.co.jp/maps?q=$publisher_address");
            $echo .= !empty($publisher_address) ? $this->getFooterTagWrapper($publisher_address, 'fas fa-map', $map_url) : "";
        }
        echo $echo;
    }

    private function getFooterTagWrapper($val, $class, $url)
    {
        return "<a class='info' href='$url'><i class='$class'></i>$val</a>";
    }

    /**
     * Register navigation menu
     * @return [type] [description]
     */
    public function registerNavigationMenus()
    {

        // wp menus
        $menus = array(
            'main-nav' => __('Main Header Bar', 'pjax-blog')   // main nav in header
        );

        $menus['mobile-nav'] = __('Mobile Menu', 'pjax-blog'); // mobile menu
        $menus['mobile-nav'] = __('Mobile Menu', 'pjax-blog'); // mobile menu

        if (leapin_is_pro()) {
            $menus['secondary-nav'] = __('Below Header Bar', 'pjax-blog'); // secondary menu in header
        }
        // registering wp3+ menus
        register_nav_menus($menus);

        return $this;
    }

    /**
     * [customiser description]
     * @return [type] [description]
     */
    public function customizer($wp_customize)
    {

        $this->registerCustomizerSettings('primary-menu', $wp_customize);
        $this->registerCustomizerSettings('mobile-menu', $wp_customize);
        if (leapin_is_pro()) {
            $this->registerCustomizerSettings('secondary-menu', $wp_customize);
        }

        return;
    }

    public function registerCustomizerSettings($file_handle = '', $wp_customize)
    {

        require_once get_template_directory() . '/inc/header/customizer/' . sanitize_title($file_handle) . '.php';

        return $this;
    }

    public function defineLogoPosition()
    {
        // if main nav is not registered and search icon is hidden.
        if (!has_nav_menu('main-nav') && !leapin_is_mod_visible(LEAPIN_IDs::$leapin_hide_primary_menu_search_icon) && !leapin_is_mod_visible(LEAPIN_IDs::$leapin_feature_hb_hide)) {
            add_filter('leapin_custom_css', function ($css) {
                // centering logo horizontally
                $css .= 'header .logo,header .logo-typo, header .logo .site-description, header .logo img, header .logo p{text-align: center;} .main-header-inner{display:none;}';
                return $css;
            });
        }
    }

    public static function getMenuType()
    {
        return self::$inst->get(LEAPIN_IDs::$leapin_secondary_menu_type, LEAPIN_Theme_Mod::$default_leapin_secondary_menu_type);
    }

    // get logo
    public static function leapin_logo($position = '')
    {
        $inst = self::$inst;
        $desktop_logo = false;
        if (has_custom_logo()) {
            $desktop_logo = get_custom_logo();
        }
        $mobile_logo = $inst->get(LEAPIN_IDs::$leapin_logo_mobile);
        $is_visible_desc = leapin_is_mod_visible(LEAPIN_IDs::$leapin_hide_site_description);

        $hide_logo_typo = '';
        $hide_mobile_logo_typo = '';

        ob_start();
        printf('<div id="logo-%s" class="main_logo%s">', $position, $is_visible_desc ? ' with-desc' : '');
        if ($desktop_logo) {
            // logo image is set
            $hide_logo_typo = 'hide_logo_typo';
            // echo desktop logo
            printf('<a href="%s" rel="nofollow"><img class="desktop-logo" src="%s" /></a>', leapin_get_home_url(), $desktop_logo);
        }
        if ($mobile_logo) {
            $hide_mobile_logo_typo = ' hide_mobile_logo_typo';
            $img = sprintf('<img class="mobile-logo" src="%s" />', $mobile_logo);
//            $img = LEAPIN_AMP_Tags::is_amp() ? sprintf('<amp-img class="mobile-logo" layout="fixed-height" src="%s" height="80"></amp-img>', $mobile_logo) : sprintf('<img class="mobile-logo" src="%s" />', $mobile_logo);
            printf('<a href="%s" rel="nofollow">%s</a>', leapin_get_home_url(), $img);
        }
        ?>
        <?php if ((is_home() || is_front_page()) && $position == 'header'): ?>
        <h1 id="logo-typo-<?php echo $position ?>"
            class="logo-typo <?php echo $hide_logo_typo . $hide_mobile_logo_typo ?>" itemscope
            itemtype="http://schema.org/Organization">
            <a href="<?php echo leapin_get_home_url(); ?>" rel="nofollow"><?php bloginfo('name'); ?></a>
        </h1>
    <?php else: ?>
        <p id="logo-typo-<?php echo $position ?>"
           class="logo-typo h1 <?php echo $hide_logo_typo . $hide_mobile_logo_typo ?>" itemscope
           itemtype="http://schema.org/Organization">
            <a href="<?php echo leapin_get_home_url(); ?>" rel="nofollow"><?php bloginfo('name'); ?></a>
        </p>
    <?php endif; ?>
        <?php if ($is_visible_desc): ?>
        <p class="site-description"><?php bloginfo('description'); ?></p>
    <?php endif; ?>
        <?php echo '</div>';
        return ob_get_clean();
    }

    public static function get_main_nav($position = 'header')
    {
        $fix = $position == 'fixed' ? ' fixed' : ' rel';

        ob_start();
        ?>
        <div class="main-header cf<?php echo $fix; ?>">
            <div class="main-header-wrapper">
                <?php echo LEAPIN_Header::get_mobile_nav_btn($position); ?>
                <?php echo LEAPIN_Header::leapin_logo($position); ?>
                <?php $theme_location = 'main-nav'; ?>
                <div class="main-header-inner">
                    <?php
                    if (has_nav_menu($theme_location) || leapin_is_mod_visible(LEAPIN_IDs::$leapin_hide_primary_menu_search_icon)) :?>
                        <nav class="primary-nav" aria-label="Navigation" itemscope
                             itemtype="http://schema.org/SiteNavigationElement">
                            <?php
                            if (has_nav_menu($theme_location)):
                                wp_nav_menu(array(
                                    'container' => false,                           // remove nav container
                                    'container_class' => 'menu cf',                 // class of container (should you choose to use it)
                                    'menu_class' => 'nav main-nav simple cf',              // adding custom nav class
                                    'theme_location' => $theme_location,                 // where it's located in the theme
                                    'link_before' => '<span class="main">',                            // before each link
                                    'link_after' => '</span>',                             // after each link
                                    'depth' => 3,                                   // limit the depth of the nav
                                    'walker' => new Menu_With_Description
                                ));
                            endif;
                            ?>
                        </nav>
                    <?php endif; ?>
                    <?php do_action('leapin_loc_on_main_header'); ?>
                </div>
            </div>
        </div>
        <?php
        return ob_get_clean();
    }

    public static function get_mobile_nav()
    {
        ob_start();
        ?>
        <aside class="mobile-nav__cr" style="display: none;">
            <div class="mobile-nav__in">
                <div class="mobile-nav__content">
                    <div class="mobile-nav__header">
                        <?php do_action('leapin_loc_top_of_mobile_nav'); ?>
                    </div>
                    <?php $theme_location = 'mobile-nav';
                    if (has_nav_menu($theme_location)):?>
                        <nav class="mobile-nav__nav" aria-label="Navigation" itemscope
                             itemtype="http://schema.org/SiteNavigationElement">
                            <?php wp_nav_menu(array(
                                'container' => false,                           // remove nav container
                                'container_class' => 'secondary cf',                 // class of container (should you choose to use it)
                                'menu_class' => 'nav mobile-nav simple cf',              // adding custom nav class
                                'theme_location' => $theme_location,                 // where it's located in the theme
                                'link_before' => '<span>',                            // before each link
                                'link_after' => '</span>',                             // after each link
                                'depth' => 3,                                   // limit the depth of the nav
                            )); ?>
                        </nav>
                        <div class="mobile-nav__footer">
                            <?php do_action('leapin_loc_end_of_mobile_nav'); ?>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
        </aside>
        <?php
        return ob_get_clean();
    }

    public static function get_mobile_nav_btn($position)
    {
        ?>
        <div id="mobile-menu-toggle-<?php echo $position; ?>" class="mobile-nav__button">
            <span class="mobile-nav__icon">&nbsp;</span>
        </div>
        <?php
    }

    public function getSearchIcon()
    {
        if (leapin_is_mod_visible(LEAPIN_IDs::$leapin_hide_primary_menu_search_icon)) {
            get_search_form();
        }
    }

    function markInitClsToBody($cls){
        $inst = self::$inst;
        $rtl = $inst->get(LEAPIN_IDs::$leapin_typography_rtl, '');
        $cls[] = !empty ($rtl) && $rtl == 'yes' ? 'rtl' : '';
        return $cls;
    }
}

// Start
$tpHeader = new LEAPIN_Header();
