<?php

/**
 * Class LEAPIN_Query_Helper
 *
 * @author LeapIn Corp.
 * @since 1.0.0
 */
class LEAPIN_Query_Helper
{

    public static $layout_type;
    public static $default_layout_type;
    public static $order_by;
    public static $default_order_by;
    public static $taxonomy = [];
    public static $default_taxonomy;
    public static $post_type = [];
    public static $default_post_type;
    public static $BEFORE_WIDGET = '<div class="widget p-0 m-0 leapin-blog-posts">';
    public static $AFTER_WIDGET = '</div>';
    public static $BEFORE_WIDGET_TITLE = '<h2 class="widget-title">';
    public static $AFTER_WIDGET_TITLE = '</h2>';
    public static $WIDGET_DUMMY_ID = 'leapin-blog-posts-1';

    private function __construct()
    {
        self::$layout_type = apply_filters('leapin_post_widget_select_layout_type',
            ['tile_ver4' => __('For Main Content Area(Tile)', 'pjax-blog'),
            'tile_ver1' => __('For Main Content Area(Bigger tile for first post)', 'pjax-blog'),
            'tile_ver2' => __('For Main Content Area(Big tiles with excerpt)', 'pjax-blog'),
            'tile_ver5' => __('For Main Content Area(Narrow tiles)', 'pjax-blog'),
            'tile_ver3' => __('For Container Area(Tiles 1)', 'pjax-blog'),
            'tile_ver6' => __('For Container Area(Tiles 2)', 'pjax-blog'),
            'sidebar_ver1' => __('For Sidebar Area(Tiles)', 'pjax-blog')
        ]);
        self::$order_by = apply_filters('leapin_post_widget_select_order_by',
            ['date' => __('Publish Date', 'pjax-blog'),
                'modified' => __('Modified Date', 'pjax-blog')
            ]);


        add_action('wp_loaded', function () {
            global $leapin_vars;
            $taxonomies = get_taxonomies(array(
                'public' => true,
//                '_builtin' => false
            ), 'objects', 'or');
            foreach ($taxonomies as $tax) {
                self::$taxonomy[$tax->name] = $tax->label;
            }
            $post_types = get_post_types(array(
                'public' => true,
                '_builtin' => false
            ), 'objects', 'or');
            foreach ($post_types as $post_type) {
                if ($post_type->name == 'attachment') continue;
                self::$post_type[$post_type->name] = $post_type->label;
            }
            $leapin_vars['taxonomies'] = apply_filters('leapin_post_widget_select_taxonomies', $taxonomies);
            $leapin_vars['post_types'] = apply_filters('leapin_post_widget_select_post_types', $post_types);

        });

        reset(self::$layout_type);
        self::$default_layout_type = key(self::$layout_type);

        reset(self::$order_by);
        self::$default_order_by = key(self::$order_by);

        reset(self::$taxonomy);
        self::$default_taxonomy = key(self::$taxonomy);

        reset(self::$post_type);
        self::$default_post_type = key(self::$post_type);
    }

    public static function init()
    {
        if (is_null(self::$layout_type) || is_null(self::$default_layout_type)) {
            new self();
        }
    }

    public static function get_post_cards_template($instance)
    {

        $post_id = get_the_ID();
        $show_date = isset($instance['show_date']) ? $instance['show_date'] : false;
        $layout_type = isset($instance['layout_type']) ? $instance['layout_type'] : false;
        $disp_excerpt = $layout_type == "tile_ver2" || $layout_type == 'swiper_ver1' || $layout_type == 'swiper_ver3' || $layout_type == 'swiper_ver4' ? "" : " no";
        // get taxonomy label and link
        $show_taxonomy = isset($instance['show_taxonomy']) ? $instance['show_taxonomy'] : false;
        $term_links = [];
        $max_term_link_count = 2;
        $thumbnail_size = isset($instance['thumbnail_size']) ? $instance['thumbnail_size'] : "leapin-medium";
        if ($layout_type == "swiper_ver1" || $layout_type == 'swiper_ver3' || $layout_type == 'swiper_ver4') {
            $thumbnail_size = "large";
        }
        $thumb_id = "thumbnail-$thumbnail_size-$post_id";
        if (!empty($show_taxonomy)) {
            $terms = wp_get_post_terms($post_id, $show_taxonomy);
            foreach ($terms as $i => $term) {
                if ($i > $max_term_link_count - 1) break;
                $term_id = $term->term_id;
                $term_label = $term->name;
                $term_url = get_term_link($term_id);
                if (!is_wp_error($term_url)) {
                    $term_links[] = sprintf('<a class="terms term-%s" href="%s">%s</a>', $term_id, $term_url, $term_label);
                }
            }
        }

        ob_start();
        ?>
        <article <?php post_class('cf card__wrap'); ?> role="article">
            <!--        <article --><?php //post_class('cf card__wrap');
            ?><!-- role="article" itemprop="blogPost" itemscope itemtype="http://schema.org/BlogPosting">-->
            <!--            <label class="card__bookmark">-->
            <!--                <input name="bookmark" type="checkbox"/>-->
            <!--                <i class="material-icons"></i>-->
            <!--            </label>-->
            <?php do_action('leapin_post_widget_disp_on_the_corner', $instance); ?>
            <?php
            $img = leapin_get_eyecatch_image($thumbnail_size);
            $thumb = $img[0];
            if (!LEAPIN_AMP_Tags::is_amp()) {
                // @todo concat ajax style
                echo "<style>.card__thumbnail.$thumb_id::after{background-image: url($thumb)}</style>";
            }
            ?>
            <div class="card__thumbnail <?php echo " " . $thumb_id; ?>" itemprop="image" itemscope
                 itemtype="https://schema.org/ImageObject">
                <a href="<?php the_permalink(); ?>" class="ripple"></a>
                <meta itemprop="url" content="<?php echo $img[0]; ?>">
                <meta itemprop="width" content="<?php echo $img[1]; ?>">
                <meta itemprop="height" content="<?php echo $img[2]; ?>">
            </div>
            <div class="card__content">
                <div class="card__header">
                    <div class="card__meta">
                        <time class="published entry-time sr-only" datetime="<?php echo get_the_date('Y-m-d'); ?>"
                              itemprop="datePublished"></time>
                        <time class="updated entry-time sr-only"
                              datetime="<?php echo get_the_modified_date('Y-m-d'); ?>" itemprop="dateModified">May 27,
                            2018
                        </time>
                        <div class="card__date<?php echo $show_date ? '' : ' sr-only'; ?>"><?php echo get_the_date(); ?></div>
                        <div class="card__taxonomy<?php echo $show_taxonomy ? '' : ' sr-only'; ?>">
                            <?php foreach ($term_links as $term_link) echo $term_link; ?>
                        </div>
                    </div>
                    <p class="card__title" itemprop="headline"><a href="<?php the_permalink(); ?>"
                        ><?php LEAPIN_Single_Tags::get_the_title(); ?></a></p>
                    <meta itemprop="mainEntityOfPage" content="<?php the_permalink(); ?>">
                </div>
                <div class="card__excerpt<?php echo $disp_excerpt ?>" itemprop="articleBody">
                    <?php
                    self::the_leapin_excerpt();
                    ?>
                </div>
                <div class="card__footer">
                    <!--                    <span class="card__favorite-counts"><i class="material-icons">favorite</i>34</span>-->
                    <?php
                    $read_more_label = leapin_get_post_meta( LEAPIN_IDs::$leapin_read_more_label_key);
                    $default_read_more_label = LEAPIN_Theme_Mod::get_instance()->get(LEAPIN_IDs::$leapin_widget_post_read_more_label, LEAPIN_Theme_Mod::$default_leapin_widget_post_read_more_label);
                    $read_more_label = !empty($read_more_label) ? $read_more_label : $default_read_more_label;
                    $is_read_more_button = $layout_type == 'swiper_ver1' || $layout_type == 'swiper_ver3' || $layout_type == 'swiper_ver4' ? true : false;
                    ?>
                    <?php if (!empty($read_more_label)): ?>
                        <?php if ($is_read_more_button): ?>
                            <a class="card__more flat_btn white ripple" href="<?php the_permalink(); ?>">
                                <?php echo $read_more_label; ?>
                            </a>
                        <?php else: ?>
                            <a class="card__more ripple" href="<?php the_permalink(); ?>">
                                <i class="fas fa-bars"></i><?php echo $read_more_label; ?>
                            </a>
                        <?php endif; ?>
                    <?php endif; ?>
                    <!--                    <div class="row entry-author author sr-only" itemprop="author" itemscope-->
                    <!--                         itemtype="https://schema.org/Person">-->
                    <!--                        <span itemprop="name"> --><?php
                    //                            $user = LEAPIN_Single_Tags::get_user_name();
                    //                            echo $user;
                    //
                    ?>
                    <!--                        </span>-->
                    <!--                    </div>-->
                    <!--                    --><?php //LEAPIN_Single_Tags::the_publisher_markup();
                    ?>
                </div>
            </div>
            <?php if ($layout_type == 'swiper_ver3' || $layout_type == 'swiper_ver1'): ?>
                <div class="swiper-pagination"></div>
            <?php endif; ?>
        </article>
        <?php
        return ob_get_clean();
    }

    public static function the_leapin_excerpt()
    {
        /**
         * this is for siteorigin
         */
        global $post;
        $old_value = apply_filters('siteorigin_panels_filter_content_enabled', true);//remember old settings
        add_filter('siteorigin_panels_filter_content_enabled', function () {
            return false;
        });
        $post_excerpt = apply_filters('the_excerpt', $post->post_excerpt);
        if (empty($post_excerpt)) {
            $post_excerpt = get_the_excerpt();
        }
        add_filter('siteorigin_panels_filter_content_enabled', function () use ($old_value) {
            return $old_value;
        });
        echo apply_filters('leapin_the_excerpt', $post_excerpt);
    }

    public static function get_nav_taxonomy_posts($instance, $the_query)
    {
        $id = get_the_ID();
        $title = get_the_title();
        $permalink = leapin_get_permalink();
        $thumbnail_url = leapin_get_eyecatch_image('leapin-medium', $id)[0];
        $call_position = $instance['call_position'];
        $level = "";
        if (!$call_position) {
            return "";
        } elseif ($call_position == "nav_level_0") {
            $level = "level-1";
        } elseif ($call_position == "nav_level_1") {
            $level = "level-2";
        }

        ob_start();
        ?>
        <?php if (LEAPIN_Query::is_first_loop($the_query)): ?>
        <ul class="sub-menu <?php echo $level ?>">
    <?php endif; ?>
        <li class="menu-item">
            <div class="img" style="background-image: url(<?php echo $thumbnail_url ?>)">
                <a class="ripple" href="<?php echo $permalink ?>"></a>
            </div>
            <a href="<?php echo $permalink ?>"><?php echo $title ?></a>
        </li>
        <?php if (LEAPIN_Query::is_last_loop($the_query)): ?>
        </ul>
    <?php endif; ?>
        <?php
        return ob_get_clean();
    }

    public static function get_nav_single($instance, $the_query)
    {
        $id = get_the_ID();
        $title = get_the_title();
        $permalink = leapin_get_permalink();
        $thumbnail_url = leapin_get_eyecatch_image('leapin-medium', $id)[0];
        $call_position = $instance['call_position'];
        $level = "";
        if (!$call_position) {
            return "";
        } elseif ($call_position == "nav_level_0") {
            $level = "level-1";
        } elseif ($call_position == "nav_level_1") {
            $level = "level-2";
        }

        ob_start();
        ?>
        <?php if (LEAPIN_Query::is_first_loop($the_query)): ?>
        <ul class="sub-menu <?php echo $level ?>">
    <?php endif; ?>
        <li class="menu-item">
            <div class="img" style="background-image: url(<?php echo $thumbnail_url ?>)">
                <a class="ripple" href="<?php echo $permalink ?>"></a>
            </div>
            <div class="desc">
                <a class="title h1" href="<?php echo $permalink ?>"><?php echo $title ?></a>
                <p class="excerpt">
                    <?php self::the_leapin_excerpt(); ?>
                </p>
            </div>
        </li>
        <?php if (LEAPIN_Query::is_last_loop($the_query)): ?>
        </ul>
    <?php endif; ?>
        <?php
        return ob_get_clean();
    }

    public static function get_post_cards($instance, $the_query)
    {
        $layout_type = isset($instance['layout_type']) ? $instance['layout_type'] : false;

        $widget_id = isset($instance['widget_args']) ? $instance['widget_args']['widget_id'] : false;
        $is_swipper = $layout_type == 'swiper_ver1' || $layout_type == 'swiper_ver2' || $layout_type == 'swiper_ver3' || $layout_type == 'swiper_ver4' ? true : false;
        $more = isset($instance['more']) ? (bool)$instance['more'] : false;
        $more_post_label = LEAPIN_Theme_Mod::get_instance()->get(LEAPIN_IDs::$leapin_widget_post_more_label, 'More');
        $paged = $instance['paged'];
        ob_start();
        ?>

        <?php if (LEAPIN_Query::is_first_loop($the_query) && !$paged) : ?>

        <?php if ($layout_type == 'swiper_ver4') : ?>
            <div class="post_cards_container_main">
        <?php endif; ?>
        <ul class="post_cards <?php echo $layout_type; ?><?php echo $is_swipper ? " swiper-wrapper" : ""; ?>">
    <?php endif; ?>

        <li class="card<?php echo $is_swipper ? " swiper-slide" : ""; ?>">
            <?php echo self::get_post_cards_template($instance); ?>
        </li>

        <?php if (LEAPIN_Query::is_last_loop($the_query) && !$paged) : ?>
        </ul>
        <?php if ($layout_type == 'swiper_ver4') : ?>
            </div>
        <?php endif; ?>
        <?php if ($more && LEAPIN_Query::is_more_posts($the_query, $instance) && !LEAPIN_AMP_Tags::is_amp()): ?>
            <?php if ($layout_type == 'tile_ver3' || $layout_type == 'tile_ver6'): ?>
                <div class="more-posts-container">
                    <a class="ajax-more-posts round_btn ripple" href="#">
                        <i class="fas fa-play"></i>
                    </a>
                </div>
            <?php elseif ($layout_type == 'sidebar_ver1'): ?>
                <div class="more-posts-container">
                    <a class="ajax-more-posts flat_btn transparent ripple"
                       href="#"><?php echo $more_post_label; ?></a>
                </div>
            <?php elseif ($layout_type == 'swiper_ver2' || $layout_type == 'swiper_ver4'): ?>
                <!-- Add Pagination -->
                <div class="swiper-pagination"></div>
            <?php elseif ($layout_type == 'swiper_ver3' || $layout_type == 'swiper_ver1'): ?>
            <?php else: ?>
                <div class="more-posts-container">
                    <a class="ajax-more-posts round_edge_btn ripple"
                       href="#"><?php echo $more_post_label; ?></a>
                </div>
            <?php endif; ?>
        <?php endif; ?>
    <?php endif; ?>

        <?php
        wp_reset_postdata();
        return ob_get_clean();
    }

    public static function get_post_background($instance, $the_query)
    {
        $post_id = get_the_ID();
        $layout_type = isset($instance['layout_type']) ? $instance['layout_type'] : false;
        $thumbnail_size = isset($instance['thumbnail_size']) ? $instance['thumbnail_size'] : "leapin-medium";
        if ($layout_type == "swiper_ver1" || $layout_type == 'swiper_ver4') {
            $thumbnail_size = "large";
        }
        $thumb_id = "thumbnail-$thumbnail_size-$post_id";
        $img = leapin_get_eyecatch_image($thumbnail_size);
        $thumb = $img[0];
        $paged = $instance['paged'];
        ob_start();
        ?>
        <?php if (LEAPIN_Query::is_first_loop($the_query) && !$paged) : ?>
        <?php if ($layout_type == 'swiper_ver4') : ?>
            <div class="post_cards_container_bg">
        <?php endif; ?>
        <ul class="post_cards swiper_ver4 swiper-wrapper">
    <?php endif; ?>

        <li class="card swiper-slide">
            <div class="card__thumbnail <?php echo $thumb_id; ?>" itemprop="image" itemscope
                 itemtype="https://schema.org/ImageObject">
                <!--                <a href="--><?php //the_permalink();
                ?><!--" class="ripple"></a>-->
                <meta itemprop="url" content="<?php echo $img[0]; ?>">
                <meta itemprop="width" content="<?php echo $img[1]; ?>">
                <meta itemprop="height" content="<?php echo $img[2]; ?>">
            </div>
        </li>

        <?php if (LEAPIN_Query::is_last_loop($the_query) && !$paged) : ?>
        </ul>
        <?php if ($layout_type == 'swiper_ver4') : ?>
            </div>
        <?php endif; ?>
    <?php endif;
        return ob_get_clean();
    }
}

LEAPIN_Query_Helper::init();