<?php

/**
 * Class LEAPIN_Single
 *
 * @author LeapIn Corp.
 * @since 1.0.0
 */
class LEAPIN_Single
{

    public static $save_post_id = null;
    private static $design_meta_fields = null;
    private static $functionality_meta_fields = null;

    public function __construct()
    {
        require_once('class-leapin-single-tags.php');
        if(empty(self::$design_meta_fields)){
            self::$design_meta_fields = [];
        }
        if(empty(self::$functionality_meta_fields)){
            self::$functionality_meta_fields = [];
        }
        $this->setPostMetaFields();
        $this->registerActionHooks();

        return $this;
    }

    public static function add_design_meta_fields($args){
        self::$design_meta_fields[] = $args;
    }

    public static function add_functionality_meta_fields($args){
        self::$functionality_meta_fields[] = $args;
    }

    public function registerActionHooks()
    {

        add_action('customize_register', array($this, 'customizer'));
        add_action('admin_menu', array($this, 'addMetaBoxes'), 10);
        add_action('leapin_loc_404_content', array($this, 'get_404_content'));
        add_filter('post_class', array($this, 'modify_post_class'));
        add_action('save_post', array($this, 'set_save_post_id'), 1);
        add_action('save_post', array($this, 'save_post_meta'));

        return $this;
    }

    public function customizer($wp_customize)
    {

        $this->registerCustomizerSettings('single', $wp_customize);

        return;
    }

    public function registerCustomizerSettings($file_handle = '', $wp_customize)
    {

        require_once get_template_directory() . '/inc/single/customizer/' . sanitize_title($file_handle) . '.php';

        return $this;
    }

    public function setPostMetaFields(){
        /**
         * Layout meta field
         */
        self::add_design_meta_fields($args = [
            "type" => "select",
            "meta_key" => LEAPIN_IDs::$leapin_layouts_single_key,
            "label" => __('Select Layout:', 'pjax-blog'),
            "choice" => LEAPIN_Theme_Mod::$choice_leapin_layouts_each_page,
            "howto" => __('Select the layout of this post.', 'pjax-blog'),
            "order" => 80
        ]);
        /**
         * Headline
         */
        self::add_design_meta_fields($args = [
            "type" => "select",
            "meta_key" => LEAPIN_IDs::$leapin_headlines_style_key,
            "label" => __('Select Headline Style:', 'pjax-blog'),
            "choice" => LEAPIN_Theme_Mod::$choice_leapin_single_headlines_style,
            "default" => LEAPIN_Theme_Mod::get_instance()->get(LEAPIN_IDs::$leapin_single_headlines_style, LEAPIN_Theme_Mod::$default_leapin_single_headlines_style),
            "howto" => __('H1 ~ H6 styles in the article.', 'pjax-blog'),
            "order" => 90
        ]);
        /**
         * SNS Button Groups
         */
        self::add_design_meta_fields($args = [
            "type" => "checkbox",
            "meta_key" => LEAPIN_IDs::$leapin_is_nosns_key,
            "label" => __('Hide SNS Button Groups', 'pjax-blog'),
            "howto" => __('Hide SNS button groups in sidebar and below the content.', 'pjax-blog'),
            "order" => 120
        ]);
        /**
         * SNS Button Groups
         */
        self::add_design_meta_fields($args = [
            "type" => "checkbox",
            "meta_key" => LEAPIN_IDs::$leapin_is_nofooter_key,
            "label" => __('Hide Article Footer', 'pjax-blog'),
            "howto" => __('Hide article footer meta below the content.', 'pjax-blog'),
            "order" => 130
        ]);

        /**
         * Read More Label
         */
        self::add_design_meta_fields($args = [
            "type" => "text",
            "meta_key" => LEAPIN_IDs::$leapin_read_more_label_key,
            "default" => LEAPIN_Theme_Mod::get_instance()->get(LEAPIN_IDs::$leapin_widget_post_read_more_label, LEAPIN_Theme_Mod::$default_leapin_widget_post_read_more_label),
            "label" => __('Button Label', 'pjax-blog'),
            "howto" => __('It\'s used for button label for [Pjax Blog] Blog Posts widget.', 'pjax-blog'),
            "order" => 140
        ]);

        if (LEAPIN_AMP_Tags::is_amp_active()) {
            self::add_functionality_meta_fields($args = [
                "type" => "checkbox",
                "meta_key" => LEAPIN_IDs::$leapin_is_noamp_key,
                "label" => __('Deactivate AMP', 'pjax-blog'),
                "howto" => __('Recommend to check this when the page containing scripts such as affiliate conversion script.', 'pjax-blog')
            ]);
        }
    }

    public function addMetaBoxes()
    {
        // set page layout
        add_meta_box(LEAPIN_IDs::$leapin_meta_box_design, __('Page Design', 'pjax-blog'), array($this, 'add_page_design_meta_box'), leapin_get_meta_box_screens(), 'side');
        add_meta_box(LEAPIN_IDs::$leapin_meta_box_functionality, __('Page Functionality', 'pjax-blog'), array($this, 'add_page_functionality_meta_box'), leapin_get_meta_box_screens(), 'side');

        return $this;
    }

    public function save_post_meta(){

        $fields = array_merge(self::$design_meta_fields, self::$functionality_meta_fields);

        foreach($fields as $field){
            $meta_key = $field['meta_key'];
            $type = $field['type'];
            $meta_value = null;
            if (isset($_POST[$meta_key])) {
                $meta_value = $_POST[$meta_key];
            }
            if(isset($meta_value) || $type === "checkbox"){
                leapin_update_post_meta($meta_key, $meta_value);
            }
        }
    }


    public function add_page_design_meta_box()
    {
        self::$design_meta_fields = leapin_array_multisort(self::$design_meta_fields, "order");
        foreach(self::$design_meta_fields as $field){
            echo leapin_add_post_meta_field($field);
        }
    }

    public function add_page_functionality_meta_box()
    {
        self::$functionality_meta_fields = leapin_array_multisort(self::$functionality_meta_fields, "order");
        foreach(self::$functionality_meta_fields as $field){
            echo leapin_add_post_meta_field($field);
        }
    }



    public function get_404_content()
    {
        get_template_part('inc/template_parts/not_found');
    }

    public function set_save_post_id(){
        self::$save_post_id = get_the_ID();
    }

    public function modify_post_class($classes){
        $style = leapin_get_post_meta( LEAPIN_IDs::$leapin_headlines_style_key );
        if(empty($style)){
            $style = LEAPIN_Theme_Mod::$default_leapin_single_headlines_style;
        }
        $classes[] = $style;
        return $classes;
    }
}

new LEAPIN_Single();
