<?php
/**
 * Class LEAPIN_Typography
 *
 * @author LeapIn Corp.
 * @since 1.0.0
 */
class LEAPIN_Typography
{

    var $defaultFontStack;
    var $defaultHeaderFont;
    var $defaultLogoFont;
    var $defaultBodyFont;
    private static $inst;


    public function __construct()
    {
        self::$inst = LEAPIN_Theme_Mod::get_instance();
        $this->defaultFontStack = LEAPIN_Theme_Mod::$default_leapin_typography_font_stack;
        $this->defaultBodyFont= LEAPIN_Theme_Mod::$default_leapin_typography_body;
        $this->defaultHeaderFont = LEAPIN_Theme_Mod::$default_leapin_typography_header;
        $this->defaultLogoFont = LEAPIN_Theme_Mod::$default_leapin_typography_logo;
        $this->registerActionHooks();

        return $this;

    }

    public function registerActionHooks()
    {

        add_action('customize_register', array($this, 'registerCustomizer'));
        add_filter('leapin_google_font', array($this, 'getUserSelectedGoogleFont'));
        add_action('wp_enqueue_scripts', array($this, 'getWebfonts'));
        add_filter('leapin_custom_css', array($this, 'stylesheet'));
        add_filter('leapin_amp_css', array($this, 'stylesheet'));
        add_filter('leapin_body_class', array($this, 'markRtlToBody'));

        return $this;

    }

    public function registerCustomizer($wp_customize)
    {

        $this->registerCustomizerSettings('options', $wp_customize);

        return $this;
    }

    public function registerCustomizerSettings($file_handle = '', $wp_customize)
    {

        require_once get_template_directory() . '/inc/typography/customizer/' . sanitize_title($file_handle) . '.php';

        return $this;
    }

    public function getUserSelectedGoogleFont()
    {
        $inst = self::$inst;
        // The font selected by the user inside the customizer.
        $body_font = $inst->get(LEAPIN_IDs::$leapin_typography_body, $this->defaultBodyFont);

        // The font selected by the user inside the customizer.
        $header_font = $inst->get(LEAPIN_IDs::$leapin_typography_header, $this->defaultHeaderFont);

        // The font selected by the user inside the customizer.
        $logo_font = $inst->get(LEAPIN_IDs::$leapin_typography_logo, $this->defaultLogoFont);

        $token = '';

        if ($body_font !== $this->defaultBodyFont) {
            $token = sprintf(
                "%s:700,400,700italic,400italic",
                $body_font
            );
        }


        if ($header_font !== $this->defaultHeaderFont && $header_font !== $body_font) {
            $sep = $body_font !== $this->defaultBodyFont ? '|' : '';
            $token .= sprintf("%s:700,400", $sep . $header_font);

        }

        if ($logo_font !== $this->defaultLogoFont && $header_font !== $logo_font && $body_font !== $logo_font) {
            $sep = $body_font !== $this->defaultBodyFont || $header_font !== $this->defaultHeaderFont ? '|' : '';
            $token .= sprintf("%s:700,400", $sep . $logo_font);

        }

        return $token;

    }

    public function getWebfonts()
    {
        $google_font = false;
        $google_font = apply_filters('leapin_google_font', $google_font);
        if (!empty($google_font)) {
            wp_enqueue_style('leapin-google-fonts', '//fonts.googleapis.com/css?family=' . $google_font);
        }
    }


    public function stylesheet($css)
    {
        $inst = self::$inst;
        require_once get_template_directory() . '/inc/typography/customizer/font-library.php';

        // Get the list of all available google fonts.
        $web_font = leapin_get_google_fonts();
        $font_stack_converter = leapin_get_default_font_stack_conv();

        // The font stack selected by the user inside the customizer.
        $entire_font = $inst->get(LEAPIN_IDs::$leapin_typography_font_stack, $this->defaultFontStack);

        // The body font selected by the user inside the customizer.
        $body_font = $inst->get(LEAPIN_IDs::$leapin_typography_body, $this->defaultBodyFont);

        // The header font selected by the user inside the customizer.
        $header_font = $inst->get(LEAPIN_IDs::$leapin_typography_header, $this->defaultHeaderFont);

        // The logo font selected by the user inside the customizer.
        $logo_font = $inst->get(LEAPIN_IDs::$leapin_typography_logo, $this->defaultLogoFont);

        // rtl direction
        $rtl = $inst->get(LEAPIN_IDs::$leapin_typography_rtl, '');

        $style = '';
        if (!empty($entire_font)) {
            $body_font_stack = $font_stack_converter[$entire_font];
            if ($body_font !== $this->defaultBodyFont) {
                $body_font_stack = $web_font[$body_font] . "," . $body_font_stack;
            }
            $style .= 'body {';
            $style .= sprintf('font-family: %s;', $body_font_stack);
            $style .= '}';
        }

        if ($header_font !== $this->defaultHeaderFont) {
            $style .= '.main-nav > li > a > span:first-child, .header-feature-button .main, .normal-title, .underline-title, .archive-title, .widget-title {';
            $style .= sprintf('font-family: "%s";', $web_font[$header_font]);
            $style .= '}';
        }

        if ($logo_font !== $this->defaultHeaderFont) {
            $style .= '.profile-card__title a, h1.logo-typo a,.logo-typo.h1 a, #logo-in_mobile_menu.h1 a{';
            $style .= sprintf('font-family: "%s";', $web_font[$logo_font]);
            $style .= '}';
        }

        if (!empty ($rtl) && $rtl == 'yes') {
            $style .= 'body {direction:rtl;}';
            $style .= 'ul.main-nav {text-align:left;}';
            $style .= 'header .logo {text-align:right;}';
            $style .= 'header .logo .site-description {text-align:right;}';
        }

        return $css . leapin_sanity_check($style);

    }

    function markRtlToBody($cls){
        $inst = self::$inst;
        $rtl = $inst->get(LEAPIN_IDs::$leapin_typography_rtl, '');
        $cls[] = !empty ($rtl) && $rtl == 'yes' ? 'rtl' : '';
        return $cls;
    }
}

new LEAPIN_Typography();
