<?php
/**
 * Class LEAPIN_Profile_Card
 *
 * @author LeapIn Corp.
 * @since 1.0.0
 */
class LEAPIN_Profile_Card extends WP_Widget
{
    /**
     * Sets up a new Pjax Blog Publisher Info Card widget instance.
     *
     * @since 1.0.0
     */
    public function __construct()
    {
        $widget_ops = array(
            'classname' => 'leapin-profile-card',
            'description' => __('Your site&#8217;s Publisher Info Card', 'pjax-blog'),
            'customize_selective_refresh' => true,
        );
        parent::__construct('leapin-profile-card', __('[Pjax Blog] Publisher Info Card', 'pjax-blog'), $widget_ops);
        $this->alt_option_name = 'leapin_widget_profile';
    }

    /**
     * Outputs the content for the current Pjax Blog Publisher Info Card widget instance.
     *
     * @since 1.0.0
     *
     * @param array $args Display arguments including 'before_title', 'after_title',
     *                        'before_widget', and 'after_widget'.
     * @param array $instance Settings for the current Pjax Blog widget instance.
     */
    public function widget($args, $instance)
    {
        if (!isset($args['widget_id'])) {
            $args['widget_id'] = $this->id;
        }

        $inst = LEAPIN_Theme_Mod::get_instance();
        $name = $inst->get(LEAPIN_IDs::$leapin_publisher_name, false);
        $logo = $inst->get(LEAPIN_IDs::$leapin_publisher_logo, false);
        $email = !empty($instance['email']) ? $inst->get(LEAPIN_IDs::$leapin_publisher_email) : false;
        $address = !empty($instance['address']) ? $inst->get(LEAPIN_IDs::$leapin_publisher_address) : false;
        $phone_num = !empty($instance['phone_num']) ? $inst->get(LEAPIN_IDs::$leapin_publisher_phone_num) : false;
        $website_url = $inst->get(LEAPIN_IDs::$leapin_publisher_website_url, '#');
        $use_image_as_logo = isset($instance['use_image_as_logo']) ? (bool)$instance['use_image_as_logo'] : false;
        $logo_color = isset($instance['logo_color']) ? esc_attr($instance['logo_color']) : '';
        $link_color = isset($instance['link_color']) ? esc_attr($instance['link_color']) : '';
        $link_color_hover = isset($instance['link_color_hover']) ? esc_attr($instance['link_color_hover']) : '';

        $title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : false;
        $title = apply_filters( 'widget_title', $title, $instance, $this->id_base );

        $echo = $args['before_widget'];
        if ( $title ) {
            $echo .= $args['before_title'] . $title . $args['after_title'];
        }

        $echo .= '<div class="profile-card" itemprop="publisher" itemscope itemtype="https://schema.org/Organization">';
        $echo .= sprintf('<meta itemprop="name" content="%s">', $name);
        if (!$use_image_as_logo) {
            $echo .= sprintf('<h4 class="profile-card__title"><a href="%s" rel="nofollow">%s</a></h4>', $website_url, $name);
        } else {
            $echo .= sprintf('<a class="profile-card__logo" href="%s" rel="nofollow"><img src="%s" /></a>', $website_url, $logo);
            $echo .= sprintf('<span itemprop="logo" itemscope itemtype="https://schema.org/ImageObject">', $website_url, $logo);
            if (!empty ($logo)) {
                $logo_info = leapin_get_image_width_and_height($logo);
                $echo .= sprintf('<meta itemprop="width" content="%s">', $logo_info['width']);
                $echo .= sprintf('<meta itemprop="height" content="%s">', $logo_info['height']);
            }
            $echo .= '</span>';
        }
        $echo .= LEAPIN_General_Settings::get_sns_links();
        if ($phone_num) {
            $echo .= sprintf('<div><i class="fas fa-phone-volume"></i><span class="profile-card__phone_num">%s</span></div>', $phone_num);
        }
        if ($email) {
            $echo .= sprintf('<div><i class="fas fa-envelope"></i><span class="profile-card__email">%s</span></div>', $email);
        }
        if ($address) {
            $echo .= sprintf('<div><i class="fas fa-map"></i><span class="profile-card__address">%s</span></div>', $address);
        }
        if(!empty($link_color) || !empty($link_color_hover) || !empty($logo_color)){
            $echo .= '<style>';
            if(!empty($link_color)){
                $echo .= '#'.$args['widget_id'].' a.icon-link i{color: '.$link_color.';}';
            }
            if(!empty($link_color_hover)){
                $echo .= '#'.$args['widget_id'].' a.icon-link:hover i{color: '.$link_color_hover.';}';
            }
            if(!empty($logo_color)) {
                $echo .= '#' . $args['widget_id'] . ' .profile-card__title a{color: ' . $logo_color . ';}';
            }
            $echo .= '</style>';
        }
        $echo .= '</div>';
        $echo .=  $args['after_widget'];
        echo $echo;
    }

    /**
     * Handles updating the settings for the current Pjax Blog widget instance.
     *
     * @since 1.0.0
     *
     * @param array $new_instance New settings for this instance as input by the user via
     *                            WP_Widget::form().
     * @param array $old_instance Old settings for this instance.
     * @return array Updated settings to save.
     */
    public function update($new_instance, $old_instance)
    {
        $instance = $old_instance;
        $instance['title'] = leapin_sanitize_text($new_instance['title']);
        $instance['logo_color'] = leapin_sanitize_text($new_instance['logo_color']);
        $instance['link_color'] = leapin_sanitize_text($new_instance['link_color']);
        $instance['link_color_hover'] = leapin_sanitize_text($new_instance['link_color_hover']);
        $instance['use_image_as_logo'] = isset($new_instance['use_image_as_logo']) ? (bool)$new_instance['use_image_as_logo'] : false;
        $instance['social_icons'] = isset($new_instance['social_icons']) ? (bool)$new_instance['social_icons'] : false;
        $instance['email'] = isset($new_instance['email']) ? (bool)$new_instance['email'] : false;
        $instance['address'] = isset($new_instance['address']) ? (bool)$new_instance['address'] : false;
        $instance['phone_num'] = isset($new_instance['phone_num']) ? (bool)$new_instance['phone_num'] : false;

        return $instance;
    }

    /**
     * Outputs the settings form for the Pjax Blog widget.
     *
     * @since 1.0.0
     *
     * @param array $instance Current settings.
     */
    public function form($instance)
    {
        $use_image_as_logo = isset($instance['use_image_as_logo']) ? (bool)$instance['use_image_as_logo'] : false;
        $title = isset($instance['title']) ? esc_attr($instance['title']) : '';
        $email = isset($instance['email']) ? (bool)$instance['email'] : false;
        $address = isset($instance['address']) ? (bool)$instance['address'] : false;
        $phone_num = isset($instance['phone_num']) ? (bool)$instance['phone_num'] : false;
        $logo_color = isset($instance['logo_color']) ? esc_attr($instance['logo_color']) : '';
        $link_color = isset($instance['link_color']) ? esc_attr($instance['link_color']) : '';
        $link_color_hover = isset($instance['link_color_hover']) ? esc_attr($instance['link_color_hover']) : '';

        ?>
        <p style="margin: 1em 0;"><?php printf(__('Please set your <a href="%s" target="_blank">Publisher Profile</a> in advance.','pjax-blog'), leapin_get_customizer_sec_url('leapin_profile_section'));?></p>
        <p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:', 'pjax-blog'); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>"
                   name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>"/></p>
        <p><input class="checkbox" type="checkbox"<?php echo checked($use_image_as_logo); ?>
                  id="<?php echo $this->get_field_id('use_image_as_logo'); ?>"
                  name="<?php echo $this->get_field_name('use_image_as_logo'); ?>"/>
            <label for="<?php echo $this->get_field_id('use_image_as_logo'); ?>"><?php _e('Show Image as Logo?', 'pjax-blog'); ?></label>
        </p>
        <p><input class="checkbox" type="checkbox"<?php echo checked($email); ?>
                  id="<?php echo $this->get_field_id('email'); ?>"
                  name="<?php echo $this->get_field_name('email'); ?>"/>
            <label for="<?php echo $this->get_field_id('email'); ?>"><?php _e('Show Email?', 'pjax-blog'); ?></label></p>
        <p><input class="checkbox" type="checkbox"<?php echo checked($address); ?>
                  id="<?php echo $this->get_field_id('address'); ?>"
                  name="<?php echo $this->get_field_name('address'); ?>"/>
            <label for="<?php echo $this->get_field_id('address'); ?>"><?php _e('Show Address?', 'pjax-blog'); ?></label></p>
        <p><input class="checkbox" type="checkbox"<?php echo checked($phone_num); ?>
                  id="<?php echo $this->get_field_id('phone_num'); ?>"
                  name="<?php echo $this->get_field_name('phone_num'); ?>"/>
            <label for="<?php echo $this->get_field_id('phone_num'); ?>"><?php _e('Show Phone Number?', 'pjax-blog'); ?></label></p>
        <p>
            <label for="<?php echo $this->get_field_id( 'logo_color' ); ?>" style="display:block;"><?php _e( 'Logo Color:' , 'pjax-blog'); ?></label>
            <input class="widefat color-picker" id="<?php echo $this->get_field_id( 'logo_color' ); ?>" name="<?php echo $this->get_field_name( 'logo_color' ); ?>" type="text" value="<?php echo esc_attr( $logo_color ); ?>" />
        </p>
        <p>
            <label for="<?php echo $this->get_field_id( 'link_color' ); ?>" style="display:block;"><?php _e( 'SNS Color:' , 'pjax-blog'); ?></label>
            <input class="widefat color-picker" id="<?php echo $this->get_field_id( 'link_color' ); ?>" name="<?php echo $this->get_field_name( 'link_color' ); ?>" type="text" value="<?php echo esc_attr( $link_color ); ?>" />
        </p>
        <p>
            <label for="<?php echo $this->get_field_id( 'link_color_hover' ); ?>" style="display:block;"><?php _e( 'SNS Color (Hover):' , 'pjax-blog'); ?></label>
            <input class="widefat color-picker" id="<?php echo $this->get_field_id( 'link_color_hover' ); ?>" name="<?php echo $this->get_field_name( 'link_color_hover' ); ?>" type="text" value="<?php echo esc_attr( $link_color_hover ); ?>" />
        </p>
        <?php
        $script  = '<script>';
        $script .= '(function($) {';
        $script .= '$(function() {';
        $script .= 'var color_change_cb_in_widget = function(event, ui){ var element = event.target; var color = ui.color.toString(); $(element).closest(\'form\').find(\'.widget-control-save\').removeAttr(\'disabled\');$(element).closest(\'form\').find(\'.widget-control-save\').val(\'Save\'); }; var options = { change: color_change_cb_in_widget};';
        $script .= '$("#' . $this->get_field_id( 'logo_color' ) . '").wpColorPicker(options);';
        $script .= '$("#' . $this->get_field_id( 'link_color' ) . '").wpColorPicker(options);';
        $script .= '$("#' . $this->get_field_id( 'link_color_hover' ) . '").wpColorPicker(options);';
        $script .= '});';
        $script .= '})(jQuery);';
        $script .= '</script>';
        echo $script;?>
        <?php
    }
}

register_widget('LEAPIN_Profile_Card');
