<?php

/**
 * Class LEAPIN_Text_Box
 *
 * @author LeapIn Corp.
 * @since 1.8.0
 */
class LEAPIN_Text_Box extends WP_Widget
{
    /**
     * Sets up a new Pjax Blog On Header Image widget instance.
     *
     * @since 1.8.0
     */
    public function __construct()
    {
        $widget_ops = array(
            'classname' => 'leapin-text-box',
            'description' => __('Your site&#8217;s Widget For Text content', 'pjax-blog'),
            'customize_selective_refresh' => true,
        );
        parent::__construct('leapin-text-box', __('[Pjax Blog] Text Box For Page Builder', 'pjax-blog'), $widget_ops);
        $this->alt_option_name = 'leapin_widget_text_box';
    }

    /**
     * Outputs the content for the current Pjax Blog On Header Image widget instance.
     *
     * @since 1.8.0
     *
     * @param array $args Display arguments including 'before_title', 'after_title',
     *                        'before_widget', and 'after_widget'.
     * @param array $instance Settings for the current Pjax Blog widget instance.
     */
    public function widget($args, $instance)
    {
        if (!isset($args['widget_id'])) {
            $args['widget_id'] = $this->id;
        }
        $id = null;
        // get id attr
        if (preg_match('/.+id=["\']([^"\']+?)["\'].+/u', $args['before_widget'], $m)) {
            $id = $m[1];
        }
        // values
//        $title_underline_color = (!empty($instance['title_underline_color'])) ? $instance['title_underline_color'] : false;
        $text_align = (!empty($instance['text_align'])) ? $instance['text_align'] : false;
        $bg_color = (!empty($instance['bg_color'])) ? $instance['bg_color'] : false;
        $font_size = (!empty($instance['font_size'])) ? $instance['font_size'] : false;
        $title_color = (!empty($instance['title_color'])) ? $instance['title_color'] : false;
        $title = (!empty($instance['title'])) ? $instance['title'] : false;
        $sub_title = (!empty($instance['sub_title'])) ? $instance['sub_title'] : false;
        $sub_title_color = (!empty($instance['sub_title_color'])) ? $instance['sub_title_color'] : false;
        $desc = (!empty($instance['desc'])) ? $instance['desc'] : false;
        $text_color = (!empty($instance['text_color'])) ? $instance['text_color'] : false;
        $icon_color = (!empty($instance['icon_color'])) ? $instance['icon_color'] : false;
        $icon_type = (!empty($instance['icon_type'])) ? $instance['icon_type'] : false;
        $icon_html = (!empty($instance['icon_html'])) ? $instance['icon_html'] : false;
        $icon_color_gradient = (!empty($instance['icon_color_gradient'])) ? $instance['icon_color_gradient'] : false;
        $icon_float = (!empty($instance['icon_float'])) ? $instance['icon_float'] : false;
        $link_type = (!empty($instance['link_type'])) ? $instance['link_type'] : false;
        $link = (!empty($instance['link_label'])) ? $instance['link_label'] : false;
        $link_color = (!empty($instance['link_color'])) ? $instance['link_color'] : false;
        $link_color_gradient = (!empty($instance['link_color_gradient'])) ? $instance['link_color_gradient'] : false;
        $url = (!empty($instance['url'])) ? $instance['url'] : false;
        $padding = (!empty($instance['padding'])) ? $instance['padding'] : false;
//        $animation = ( ! empty( $instance['animation'] ) ) ? $instance['animation'] : false;

        // attr
        $icon_attr = null;
        $widget_wrap_class = null;
        $before_title = $args['before_title'];
        $title_class_value = null;
        $icon_css = null;
//        $title_underline_color_css = "";
        $icon_float_css = "";
        $link_css = null;
        $link_float_css = "";


        // design
        $title_class_value = "lp-tile__title normal-title";
//        $title_class_value = "lp-tile__title";
//        if ($title_underline_color) {
//            $title_class_value .= " underline-title";
//            $title_underline_color_css = "#$id .underline-title::before{background-color: $title_underline_color;}";
//        } else {
//            $title_class_value .= " normal-title";
//        }

        // subtitle
        if ($sub_title) {
            $title_class_value .= " with-subtitle";
        }
        // align
        $widget_wrap_class = "lp-tile";
        if ($text_align === "left") {
            $widget_wrap_class .= " text-align-left";
        } else if ($text_align === "right") {
            $widget_wrap_class .= " text-align-right";
        }
        $widget_wrap_class .= " font-$font_size";

        // padding
        if ($padding === "large") {
            $widget_wrap_class .= " p-l";
        } else if ($padding === "larger") {
            $widget_wrap_class .= " p-lr";
        } else if ($padding === "smaller") {
            $widget_wrap_class .= " p-sr";
        } else if ($padding === "none") {
            $widget_wrap_class .= " p-n";
        } else {
            // normal
        }
        // echo start
        $echo = $args['before_widget'];
        $echo .= "<div class=\"$widget_wrap_class\">";
        // icon
        if ($icon_html) {
            if (!empty($icon_float)) {
                $icon_float_css = "box-shadow: 5px 5px 30px -8px $icon_color;";
            }
            $echo .= "<div class=\"lp-tile__icon $icon_type\">$icon_html</div>";
            $icon_css = "#$id .lp-tile__icon.$icon_type{background-color: $icon_color;$icon_float_css}";
        }
        if (isset($icon_css) && $icon_color_gradient) {
            $icon_css = "#$id .lp-tile__icon{background: linear-gradient(110deg, $icon_color, $icon_color_gradient);$icon_float_css}";
        }
        // title container
        if ($title || $sub_title) {
            if (!$link && !$icon_html) {
                $echo .= "<div class=\"lp-tile__title-container m-n\">";
            } else {
                $echo .= "<div class=\"lp-tile__title-container\">";
            }
        }

        // title
        if ($title) {
            if (preg_match('/^<(\w+).+>/u', $before_title, $m)) {
                $before_title = "<$m[1] class=\"$title_class_value\">";
            }
            $echo .= $before_title . $title . $args['after_title'];
        }
        // subtitle
        if ($sub_title) {
            $echo .= "<p class='lp-tile__subtitle'>$sub_title</p>";
        }
        // title container close
        if ($title || $sub_title) {
            $echo .= "</div>";
        }
        // desc
        if ($desc) {
            $echo .= "<p class='lp-tile__desc'>$desc</p>";
        }
        // link & button
        if ($link && $url) {
            $link_size = $font_size ? " large" : "";
            $link_mg = (!$title || !$sub_title || !$desc) ? " m-n" : "";

            if ($link_type === "text") {
                $echo .= "<a class='lp-tile__link text_more_link{$link_size}{$link_mg}' href='$url'>$link</a>";
                if($link_color){
                    $link_css = "#$id .lp-tile__link{color:$link_color}";
                }
            } else {
                $echo .= "<a class='lp-tile__link flat_btn box-shadow{$link_size}{$link_mg}' href='$url'>$link</a>";
                if($link_color) {
                    $link_float_css = "box-shadow: 5px 5px 30px -8px $link_color;";
                    $link_css = "#$id .flat_btn{background:$link_color;$link_float_css}";
                }
                if(isset($link_css) && $link_color_gradient){
                    $link_css = "#$id .flat_btn{background: linear-gradient(110deg, $link_color, $link_color_gradient);$link_float_css}";
                }
            }
        }


        $echo .= "</div>" . $args['after_widget'];

        $css = "";
        // make css string
        if ($bg_color) {
            $css .= "#$id .lp-tile{background:$bg_color}";
        }
        if ($sub_title_color) {
            $css .= "#$id .lp-tile__subtitle{color:$sub_title_color}";
        }
        if ($title_color) {
            $css .= "#$id .lp-tile__title{color:$title_color}";
        }
        if ($icon_color) {
            $css .= "#$id .lp-tile .$title_class_value::before{background:$icon_color}";
        }
        if ($text_color) {
            $css .= "#$id .lp-tile .lp-tile__desc{color:$text_color}";
        }
        $css .= $icon_css;
        $css .= $link_css;
//        $css .= $title_underline_color_css;

        if (!empty($id)) {
            add_filter('leapin_load_css_on_each_pjax', function ($css_concat) use ($css) {
                return $css_concat . $css;
            });
        }
        echo $echo;
    }

    /**
     * Handles updating the settings for the current Pjax Blog widget instance.
     *
     * @since 1.8.0
     *
     * @param array $new_instance New settings for this instance as input by the user via
     *                            WP_Widget::form().
     * @param array $old_instance Old settings for this instance.
     * @return array Updated settings to save.
     */
    public function update($new_instance, $old_instance)
    {
        $instance = $old_instance;
        $instance['text_align'] = leapin_sanitize_text($new_instance['text_align']);
//        $instance['title_underline_color'] = leapin_sanitize_text($new_instance['title_underline_color']);
        $instance['title_color'] = leapin_sanitize_text($new_instance['title_color']);
        $instance['bg_color'] = leapin_sanitize_rgba_color($new_instance['bg_color']);
        $instance['font_size'] = leapin_sanitize_text($new_instance['font_size']);
        $instance['title'] = leapin_sanitize_text($new_instance['title']);
        $instance['sub_title'] = leapin_sanitize_text($new_instance['sub_title']);
        $instance['sub_title_color'] = leapin_sanitize_text($new_instance['sub_title_color']);
        $instance['desc'] = leapin_sanitize_mock($new_instance['desc']);
        $instance['text_color'] = leapin_sanitize_rgba_color($new_instance['text_color']);
        $instance['icon_color'] = leapin_sanitize_rgba_color($new_instance['icon_color']);
        $instance['icon_type'] = leapin_sanitize_text($new_instance['icon_type']);
        $instance['icon_html'] = wp_kses_post($new_instance['icon_html']);
        $instance['icon_color_gradient'] = leapin_sanitize_rgba_color($new_instance['icon_color_gradient']);
        $instance['icon_float'] = leapin_sanitize_checkbox($new_instance['icon_float']);
        $instance['link_type'] = leapin_sanitize_text($new_instance['link_type']);
        $instance['link_color'] = leapin_sanitize_text($new_instance['link_color']);
        $instance['link_color_gradient'] = leapin_sanitize_text($new_instance['link_color_gradient']);
        $instance['link_label'] = wp_kses_post($new_instance['link_label']);
        $instance['url'] = esc_url_raw($new_instance['url']);
        $instance['padding'] = leapin_sanitize_text($new_instance['padding']);
//        $instance['animation'] = leapin_sanitize_text($new_instance['animation']);

        return $instance;
    }

    /**
     * Outputs the settings form for the Pjax Blog widget.
     *
     * @since 1.8.0
     *
     * @param array $instance Current settings.
     */
    public function form($instance)
    {
        ?>
        <p style="margin: 1em 0;"><?php _e('This widget is useful to build grid layout page with Page Builder.', 'pjax-blog') ?></p>
        <?php
        /************************************************************************
         * Entire Settings
         */
        leapin_add_large_title_to_widget_form(__('Entire Settings', 'pjax-blog'));

        /**
         * Text Align
         */
        leapin_add_select_to_widget_form($this, $instance, 'text_align', [
            'label' => __('Text Align:', 'pjax-blog'),
            'choice' => [
                'left' => __('Left', 'pjax-blog'),
                'center' => __('Center', 'pjax-blog'),
                'right' => __('Right', 'pjax-blog'),
            ],
            'default' => 'left'
        ]);
        /**
         * Font Size
         */
        leapin_add_select_to_widget_form($this, $instance, 'font_size', [
            'label' => __('Font Size:', 'pjax-blog'),
            'choice' => [
                'larger' => __('Larger', 'pjax-blog'),
                'normal' => __('Normal', 'pjax-blog'),
                'smaller' => __('Smaller', 'pjax-blog'),
            ],
            'default' => 'normal'
        ]);

        /**
         * Background Color
         */
        leapin_add_color_picker_to_widget_form($this, $instance, 'bg_color', [
            'label' => __('Background Color:', 'pjax-blog'),
            'show_opacity' => true
        ]);

        /**
         * Padding
         */
        leapin_add_select_to_widget_form($this, $instance, 'padding', [
            'label' => __('Wrapper Padding:', 'pjax-blog'),
            'choice' => [
                'large' => __('Large', 'pjax-blog'),
                'larger' => __('Larger', 'pjax-blog'),
                'normal' => __('Normal', 'pjax-blog'),
                'smaller' => __('Smaller', 'pjax-blog'),
                'none' => __('None', 'pjax-blog'),
            ],
            'default' => 'normal'
        ]);
        /************************************************************************
         * Text Fields
         */
        leapin_add_large_title_to_widget_form(__('Text Fields', 'pjax-blog'));

        /**
         * Title
         */
        leapin_add_text_to_widget_form($this, $instance, 'title', [
            'label' => __('Title:', 'pjax-blog'),
        ]);
        /**
         * Title Color
         */
        leapin_add_color_picker_to_widget_form($this, $instance, 'title_color', [
            'label' => __('Title Color:', 'pjax-blog'),
            'show_opacity' => true
        ]);
        /**
         * Subtitle
         */
        leapin_add_text_to_widget_form($this, $instance, 'sub_title', [
            'label' => __('Subtitle:', 'pjax-blog'),
        ]);
        /**
         * Subtitle Color
         */
        leapin_add_color_picker_to_widget_form($this, $instance, 'sub_title_color', [
            'label' => __('Subtitle Color:', 'pjax-blog'),
            'show_opacity' => true
        ]);
        /**
         * Title Underline Color
         */
//        leapin_add_color_picker_to_widget_form($this, $instance, 'title_underline_color', [
//            'label' => __('Title Underline Color:', 'pjax-blog'),
//            'show_opacity' => true
//        ]);
        /**
         * Content
         */
        leapin_add_textarea_to_widget_form($this, $instance, 'desc', [
            'label' => __('Description (HTML tags can be used):', 'pjax-blog'),
        ]);
        /**
         * Text Color
         */
        leapin_add_color_picker_to_widget_form($this, $instance, 'text_color', [
            'label' => __('Text Color:', 'pjax-blog'),
            'show_opacity' => true
        ]);

        /************************************************************************
         * Link Option
         */
        leapin_add_large_title_to_widget_form(__('Link Option', 'pjax-blog'));

        /**
         * Link Type
         */
        leapin_add_select_to_widget_form($this, $instance, 'link_type', [
            'label' => __('Link Type:', 'pjax-blog'),
            'choice' => [
                'text' => __('Text', 'pjax-blog'),
                'flat_btn' => __('Flat Button', 'pjax-blog')
            ],
            'default' => 'text'
        ]);
        /**
         * Link Label
         */
        leapin_add_text_to_widget_form($this, $instance, 'link_label', [
            'label' => sprintf(__('Link Label: <a target="_blank" href="%s">See available fonts in FontAwesome</a>', 'pjax-blog'), "https://fontawesome.com/icons?d=gallery&m=free"),
        ]);
        /**
         * Link URL
         */
        leapin_add_text_to_widget_form($this, $instance, 'url', [
            'label' => __('Link URL:', 'pjax-blog'),
        ]);
        /**
         * Link Color
         */
        leapin_add_color_picker_to_widget_form($this, $instance, 'link_color', [
            'label' => __('Link Color:', 'pjax-blog'),
        ]);
        /**
         * Link Gradient Color
         */
        leapin_add_color_picker_to_widget_form($this, $instance, 'link_color_gradient', [
            'label' => __('Link Gradient Color:', 'pjax-blog'),
            'show_opacity' => true
        ]);

        /************************************************************************
         * Icon Option
         */
        leapin_add_large_title_to_widget_form(__('Icon Option', 'pjax-blog'));
        /**
         * Icon Type
         */
        leapin_add_select_to_widget_form($this, $instance, 'icon_type', [
            'label' => __('Icon Type:', 'pjax-blog'),
            'choice' => [
                'round' => __('Round', 'pjax-blog'),
                'rounded_corners' => __('Rounded Rectangular', 'pjax-blog')
            ],
            'default' => 'round'
        ]);
        /**
         * Icon
         */
        leapin_add_text_to_widget_form($this, $instance, 'icon_html', [
            'label' => sprintf(__('Icon: <a target="_blank" href="%s">See available fonts in FontAwesome</a>', 'pjax-blog'), "https://fontawesome.com/icons?d=gallery&m=free"),
            'default' => esc_html('<i class="far fa-bell"></i>')
        ]);
        /**
         * Icon Float
         */
        leapin_add_checkbox_to_widget_form($this, $instance, 'icon_float', [
            'label' => __('Float Icon:', 'pjax-blog')
        ]);
        /**
         * Icon Color
         */
        leapin_add_color_picker_to_widget_form($this, $instance, 'icon_color', [
            'label' => __('Icon Color:', 'pjax-blog'),
            'show_opacity' => false
        ]);
        /**
         * Icon Gradient Color
         */
        leapin_add_color_picker_to_widget_form($this, $instance, 'icon_color_gradient', [
            'label' => __('Icon Gradient Color:', 'pjax-blog'),
            'show_opacity' => true
        ]);

    }
}

register_widget('LEAPIN_Text_Box');
