<?php

/**
 * Class LEAPIN_Widget_Posts
 *
 * @author LeapIn Corp.
 * @since 1.0.0
 */
class LEAPIN_Widget_Posts extends WP_Widget
{
    /**
     * Sets up a new Pjax Blog Post widget instance.
     *
     * @since 1.0.0
     */
    public function __construct()
    {
        $widget_ops = array(
            'classname' => 'leapin-blog-posts',
            'description' => __('Your site&#8217;s Beautiful Posts', 'pjax-blog'),
            'customize_selective_refresh' => true,
        );
        parent::__construct('leapin-blog-posts', __('[Pjax Blog] Blog Posts', 'pjax-blog'), $widget_ops);
        $this->alt_option_name = 'leapin_widget_entries';
    }

    /**
     * Outputs the content for the current Pjax Blog Post widget instance.
     *
     * @since 1.0.0
     *
     * @param array $args Display arguments including 'before_title', 'after_title',
     *                        'before_widget', and 'after_widget'.
     * @param array $instance Settings for the current Pjax Blog widget instance.
     */
    public function widget($args, $instance)
    {
        if (!isset($args['widget_id'])) {
            $args['widget_id'] = $this->id;
            $instance['widget_args'] = $args;
        }

        $cq = new LEAPIN_Query($instance, $args);
        $cq->ajax_or_print();

    }

    /**
     * Handles updating the settings for the current Pjax Blog widget instance.
     *
     * @since 1.0.0
     *
     * @param array $new_instance New settings for this instance as input by the user via
     *                            WP_Widget::form().
     * @param array $old_instance Old settings for this instance.
     * @return array Updated settings to save.
     */
    public function update($new_instance, $old_instance)
    {
        $instance = $old_instance;
        $instance['title'] = leapin_sanitize_text($new_instance['title']);
        $instance['theme_color'] = leapin_sanitize_rgba_color($new_instance['theme_color']);
        $instance['posts_per_page'] = (int)$new_instance['posts_per_page'];
        $instance['show_date'] = isset($new_instance['show_date']) ? (bool)$new_instance['show_date'] : false;
        $instance['swiper_loop'] = isset($new_instance['swiper_loop']) ? (bool)$new_instance['swiper_loop'] : false;
        $instance['related_post'] = isset($new_instance['related_post']) ? (bool)$new_instance['related_post'] : false;
        $instance['show_view_count'] = isset($new_instance['show_view_count']) ? (bool)$new_instance['show_view_count'] : false;
        $instance['show_taxonomy'] = leapin_sanitize_text($new_instance['show_taxonomy']);
        $instance['post_type'] = leapin_sanitize_text($new_instance['post_type']);
        $instance['ajax'] = isset($new_instance['ajax']) ? $new_instance['ajax'] : false;
        $instance['more'] = isset($new_instance['more']) ? (bool)$new_instance['more'] : false;
        $instance['layout_type'] = leapin_sanitize_text($new_instance['layout_type']);
        $instance['taxonomy'] = leapin_sanitize_text($new_instance['taxonomy']);
        $instance['term_ids_or_slugs'] = leapin_sanitize_text($new_instance['term_ids_or_slugs']);
        $instance['custom_fields'] = leapin_sanitize_text($new_instance['custom_fields']);
        $instance['post_ids'] = leapin_sanitize_text($new_instance['post_ids']);
        $instance['exclude_post_ids'] = leapin_sanitize_text($new_instance['exclude_post_ids']);
        $instance['order_by'] = leapin_sanitize_text($new_instance['order_by']);
        $instance['grayscale'] = leapin_sanitize_text($new_instance['grayscale']);

        return $instance;
    }

    /**
     * Outputs the settings form for the Pjax Blog widget.
     *
     * @since 1.0.0
     *
     * @param array $instance Current settings.
     */
    public function form($instance)
    {
        $title = isset($instance['title']) ? esc_attr($instance['title']) : '';
        $posts_per_page = isset($instance['posts_per_page']) ? absint($instance['posts_per_page']) : 5;
        $layout_type = isset($instance['layout_type']) ? $instance['layout_type'] : LEAPIN_Query_Helper::$default_layout_type;
        $show_date = isset($instance['show_date']) ? (bool)$instance['show_date'] : false;
        $related_post = isset($instance['related_post']) ? (bool)$instance['related_post'] : false;
        $show_view_count = isset($instance['show_view_count']) ? (bool)$instance['show_view_count'] : false;
        $show_taxonomy = isset($instance['show_taxonomy']) ? $instance['show_taxonomy'] : "";
        $post_type = isset($instance['post_type']) ? $instance['post_type'] : LEAPIN_Query_Helper::$default_post_type;
//        $show_favorite_button = isset($instance['show_favorite_button']) ? (bool)$instance['show_favorite_button'] : true;
        $ajax = isset($instance['ajax']) ? $instance['ajax'] : "leapin_posts";
//        $animation = isset($instance['animation']) ? (bool)$instance['animation'] : true;
        $more = isset($instance['more']) ? (bool)$instance['more'] : false;
        $taxonomy = isset($instance['taxonomy']) ? $instance['taxonomy'] : "-";
        $term_ids_or_slugs = isset($instance['term_ids_or_slugs']) ? esc_attr($instance['term_ids_or_slugs']) : '';
        $custom_fields = isset($instance['custom_fields']) ? esc_attr($instance['custom_fields']) : '';
        $post_ids = isset($instance['post_ids']) ? esc_attr($instance['post_ids']) : '';
        $exclude_post_ids = isset($instance['exclude_post_ids']) ? esc_attr($instance['exclude_post_ids']) : '';
        $order_by = isset($instance['order_by']) ? $instance['order_by'] : LEAPIN_Query_Helper::$default_order_by;
        $grayscale = isset($instance['grayscale']) || (array_key_exists('grayscale', $instance) && $instance['grayscale'] === 0)
            ? esc_attr($instance['grayscale']) : 30;
        $swiper_loop = isset($instance['swiper_loop']) ? (bool)$instance['swiper_loop'] : false;
        $theme_color = isset($instance['theme_color']) ? esc_attr($instance['theme_color']) : '';
        ?>
        <?php
        /**
         * Display Options
         */
        ?>
        <p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:', 'pjax-blog'); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>"
                   name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>"/></p>

        <p style="font-weight: 600;margin-top: 20px;font-size: 21px;"><?php _e('Display options', 'pjax-blog') ?></p>
        <?php
        printf(
            '<p><label for="%1$s">%2$s</label><select class="widefat" id="%1$s" name="%3$s">',
            $this->get_field_id('layout_type'),
            __('Layout:', 'pjax-blog'),
            $this->get_field_name('layout_type')
        );

        foreach (LEAPIN_Query_Helper::$layout_type as $value => $option_name) {
            printf(
                '<option value="%s"%s>%s</option>',
                esc_attr($value),
                selected($value, $layout_type, false),
                $option_name
            );
        }
        echo '</select></p>';
        ?>
        <p>
            <label for="<?php echo $this->get_field_id('posts_per_page'); ?>"><?php _e('Number of posts to show:', 'pjax-blog'); ?></label>
            <input class="tiny-text" id="<?php echo $this->get_field_id('posts_per_page'); ?>"
                   name="<?php echo $this->get_field_name('posts_per_page'); ?>" type="number" step="1" min="1"
                   value="<?php echo $posts_per_page; ?>" size="3"/></p>
        <p><input class="checkbox" type="checkbox"<?php echo checked($show_date); ?>
                  id="<?php echo $this->get_field_id('show_date'); ?>"
                  name="<?php echo $this->get_field_name('show_date'); ?>"/>
            <label for="<?php echo $this->get_field_id('show_date'); ?>"><?php _e('Display post date?', 'pjax-blog'); ?></label>
        </p>
        <?php if(leapin_is_pro()) :?>
        <p><input class="checkbox" type="checkbox"<?php echo checked($show_view_count); ?>
                  id="<?php echo $this->get_field_id('show_view_count'); ?>"
                  name="<?php echo $this->get_field_name('show_view_count'); ?>"/>
            <label for="<?php echo $this->get_field_id('show_view_count'); ?>"><?php _e('Display post view count?', 'pjax-blog'); ?></label>
        </p>
        <?php endif; ?>
        <!--        <p><input class="checkbox" type="checkbox"--><?php //echo checked($show_favorite_button);
        ?>
        <!--                  id="--><?php //echo $this->get_field_id('show_favorite_button');
        ?><!--"-->
        <!--                  name="--><?php //echo $this->get_field_name('show_favorite_button');
        ?><!--"/>-->
        <!--            <label for="--><?php //echo $this->get_field_id('show_favorite_button');
        ?><!--">--><?php //_e('Display Favorite Button?');
        ?><!--</label>-->
        <!--        </p>-->
        <!--        <p><input class="checkbox" type="checkbox"--><?php //echo checked($animation);
        ?>
        <!--                  id="--><?php //echo $this->get_field_id('animation');
        ?><!--"-->
        <!--                  name="--><?php //echo $this->get_field_name('animation');
        ?><!--"/>-->
        <!--            <label for="--><?php //echo $this->get_field_id('animation');
        ?><!--">--><?php //_e('Display posts with animation?');
        ?><!--</label>-->
        <!--        </p>-->
        <p><input class="checkbox" type="checkbox"<?php echo checked($more); ?>
                  id="<?php echo $this->get_field_id('more'); ?>"
                  name="<?php echo $this->get_field_name('more'); ?>"/>
            <label for="<?php echo $this->get_field_id('more'); ?>"><?php _e('Display a button to fetch more posts.(Pagenation appear, depending on the layout type, instead.)', 'pjax-blog'); ?></label>
        </p>
        <p>
            <label for="<?php echo $this->get_field_id('grayscale'); ?>"><?php _e('Thumbnail overlay grayscale(0 - 100%):', 'pjax-blog'); ?></label>
            <input class="tiny-text" id="<?php echo $this->get_field_id('grayscale'); ?>"
                   name="<?php echo $this->get_field_name('grayscale'); ?>" type="number" min="0" max="100"
                   value="<?php echo $grayscale; ?>"/></p>

        <?php
        printf(
            '<p><label for="%1$s">%2$s</label><select class="widefat" id="%1$s" name="%3$s">',
            $this->get_field_id('show_taxonomy'),
            __('Show Type of Taxonomy Link:', 'pjax-blog'),
            $this->get_field_name('show_taxonomy')
        );
        echo '<option value="">--</option>';
        foreach (LEAPIN_Query_Helper::$taxonomy as $name => $label) {
            printf(
                '<option value="%s"%s>%s</option>',
                esc_attr($name),
                selected($name, $show_taxonomy, false),
                $label
            );
        }
        echo '</select></p>';
        printf(
            '<p><label for="%1$s">%2$s</label><select class="widefat" id="%1$s" name="%3$s">',
            $this->get_field_id('order_by'),
            __('Order by:', 'pjax-blog'),
            $this->get_field_name('order_by')
        );

        foreach (LEAPIN_Query_Helper::$order_by as $value => $option_name) {
            printf(
                '<option value="%s"%s>%s</option>',
                esc_attr($value),
                selected($value, $order_by, false),
                $option_name
            );
        }
        echo '</select></p>';
        ?>
        <p>
            <label for="<?php echo $this->get_field_id( 'theme_color' ); ?>" style="display:block;"><?php _e( 'Widget Theme Color:', 'pjax-blog' ); ?></label>
            <input class="widefat color-picker" id="<?php echo $this->get_field_id( 'theme_color' ); ?>" name="<?php echo $this->get_field_name( 'theme_color' ); ?>" type="text" value="<?php echo $theme_color; ?>" />
        </p>
        <p style="margin: 1em 0;">Please set other <a href="<?php echo leapin_get_customizer_sec_url('leapin_widget_section');?>" target="_blank"><?php _e('global variables','pjax-blog'); ?></a> to decorate this widget.</p>
        <?php
        /**
         * Filter Options
         */
        ?>
        <p style="font-weight: 600;margin-top: 20px;font-size: 21px;"><?php _e('Filter options', 'pjax-blog') ?></p>

        <?php
        printf(
            '<p><label for="%1$s">%2$s</label><select class="widefat" id="%1$s" name="%3$s">',
            $this->get_field_id('post_type'),
            __('Post Type:', 'pjax-blog'),
            $this->get_field_name('post_type')
        );
        foreach (LEAPIN_Query_Helper::$post_type as $name => $label) {
            printf(
                '<option value="%s"%s>%s</option>',
                esc_attr($name),
                selected($name, $post_type, false),
                $label
            );
        }
        echo '<option value="any"' . selected("any", $post_type, false) . '>' . __('Any (may slow down page load speed)', 'pjax-blog') . '</option>';
        echo '</select></p>';

        printf(
            '<p><label for="%1$s">%2$s</label><select class="widefat" id="%1$s" name="%3$s">',
            $this->get_field_id('taxonomy'),
            __('Taxonomy:', 'pjax-blog'),
            $this->get_field_name('taxonomy')
        );

        echo '<option value="">--</option>';
        foreach (LEAPIN_Query_Helper::$taxonomy as $name => $label) {
            printf(
                '<option value="%s"%s>%s</option>',
                esc_attr($name),
                selected($name, $taxonomy, false),
                $label
            );
        }
        echo '</select></p>';
        ?>
        <p><input class="checkbox" type="checkbox"<?php echo checked($related_post); ?>
                  id="<?php echo $this->get_field_id('related_post'); ?>"
                  name="<?php echo $this->get_field_name('related_post'); ?>"/>
            <label for="<?php echo $this->get_field_id('related_post'); ?>"><?php _e('Display posts related to tags, categories of the page?', 'pjax-blog'); ?></label>
        </p>
        <p>
            <label for="<?php echo $this->get_field_id('term_ids_or_slugs'); ?>"><?php _e('Terms IDs or Slugs(comma separated):', 'pjax-blog'); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id('term_ids_or_slugs'); ?>"
                   name="<?php echo $this->get_field_name('term_ids_or_slugs'); ?>" type="text"
                   value="<?php echo $term_ids_or_slugs; ?>"/></p>

        <p>
            <label for="<?php echo $this->get_field_id('custom_fields'); ?>"><?php _e('Custom Fields(key=value1,value2,..):', 'pjax-blog'); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id('custom_fields'); ?>"
                   name="<?php echo $this->get_field_name('custom_fields'); ?>" type="text"
                   value="<?php echo $custom_fields; ?>"/></p>

        <p><label for="<?php echo $this->get_field_id('post_ids'); ?>"><?php _e('Post IDs(comma separated):', 'pjax-blog'); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id('post_ids'); ?>"
                   name="<?php echo $this->get_field_name('post_ids'); ?>" type="text"
                   value="<?php echo $post_ids; ?>"/></p>

        <p>
            <label for="<?php echo $this->get_field_id('exclude_post_ids'); ?>"><?php _e('Exclude post IDs(comma separated):', 'pjax-blog'); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id('exclude_post_ids'); ?>"
                   name="<?php echo $this->get_field_name('exclude_post_ids'); ?>" type="text"
                   value="<?php echo $exclude_post_ids; ?>"/></p>
        <p style="font-weight: 600;margin-top: 20px;font-size: 21px;"><?php _e('Other options', 'pjax-blog') ?></p>
        <p><input class="checkbox" type="checkbox" value="leapin_posts"<?php echo checked($ajax, "leapin_posts"); ?>
                  id="<?php echo $this->get_field_id('ajax'); ?>"
                  name="<?php echo $this->get_field_name('ajax'); ?>"/>
            <label for="<?php echo $this->get_field_id('ajax'); ?>"><?php _e('Get post with ajax?', 'pjax-blog'); ?></label>
        </p>
        <?php
    }
}

register_widget('LEAPIN_Widget_Posts');
