<?php

/**
 * class LEAPIN_Widgets
 *
 * @author LeapIn Corp.
 * @since 1.0.0
 */
class LEAPIN_Widgets
{

    public function __construct()
    {

        $this->registerActionHooks();

        return $this;
    }

    public function registerActionHooks()
    {

        add_action('widgets_init', array($this, 'registerWidgetsArea'));
        add_action('widgets_init', array($this, 'registerWidgets'), 1);
        add_action('customize_register', array($this, 'registerCustomizer'));
        add_filter('leapin_custom_css', array($this, 'setStyle'));

        return $this;
    }

    public function registerWidgets()
    {
        require_once('modules/leapin_widget_posts.php');
        require_once('modules/leapin_profile_card.php');
        require_once('modules/leapin_on_header_image.php');
        return $this;
    }

    public function registerWidgetsArea()
    {

        register_sidebar(array(
            'id' => 'sidebar1',
            'name' => __('Sidebar', 'pjax-blog'),
            'description' => __('The first sidebar.', 'pjax-blog'),
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h2 class="widget-title"><span>',
            'after_title' => '</span></h2>',
        ));
        register_sidebar(array(
            'id' => 'on_custom_header_image',
            'name' => __('On Header Image', 'pjax-blog'),
            'description' => __('Widget area on custom header image. Please Use <code>On Header Image Widget</code>. Add One Widget per One Slide.', 'pjax-blog'),
            'before_widget' => '<div id="%1$s" class="widget p-0 m-0 %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h2 class="widget-title">',
            'after_title' => '</h2>',
        ));
        register_sidebar(array(
            'id' => 'above_container',
            'name' => __('Above Container', 'pjax-blog'),
            'description' => __('Widget area above container.', 'pjax-blog'),
            'before_widget' => '<div id="%1$s" class="widget p-0 m-0 %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h2 class="widget-title">',
            'after_title' => '</h2>',
        ));
        register_sidebar(array(
            'id' => 'above_single_content',
            'name' => __('Above Post/Page Content', 'pjax-blog'),
            'description' => __('Widget area above post and page content.', 'pjax-blog'),
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h2 class="widget-title">',
            'after_title' => '</h2>',
        ));
        register_sidebar(array(
            'id' => 'above_single_footer_meta',
            'name' => __('Above Post/Page Footer Content', 'pjax-blog'),
            'description' => __('Widget area above post footer meta content.', 'pjax-blog'),
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h2 class="widget-title">',
            'after_title' => '</h2>',
        ));
        register_sidebar(array(
            'id' => 'below_single_content',
            'name' => __('Below Post/Page Content', 'pjax-blog'),
            'description' => __('Widget area below post content.', 'pjax-blog'),
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h2 class="widget-title">',
            'after_title' => '</h2>',
        ));
        register_sidebar(array(
            'id' => 'sidebar_single',
            'name' => __('Sidebar in Post/Page', 'pjax-blog'),
            'description' => __('sidebar in a single post or page.', 'pjax-blog'),
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h2 class="widget-title"><span>',
            'after_title' => '</span></h2>',
        ));
        register_sidebar(array(
            'id' => 'below_container',
            'name' => __('Below Container', 'pjax-blog'),
            'description' => __('Widget area below container.', 'pjax-blog'),
            'before_widget' => '<div id="%1$s" class="widget p-0 m-0 %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h2 class="widget-title">',
            'after_title' => '</h2>',
        ));

        return $this;
    }

    public function registerCustomizer($wp_customize)
    {

        $this->registerCustomizerSettings('widgets', $wp_customize);

        return $this;
    }

    public function registerCustomizerSettings($file_handle = '', $wp_customize)
    {

        require_once get_template_directory() . '/inc/widgets/customizer/' . sanitize_title($file_handle) . '.php';

        return $this;
    }

    public function setStyle($css)
    {
        $inst = LEAPIN_Theme_Mod::get_instance();
        $sidebar_widget_title_type = $inst->get(LEAPIN_IDs::$leapin_sidebar_widget_title_type, LEAPIN_Theme_Mod::$default_leapin_sidebar_widget_title_type);
        if ($sidebar_widget_title_type == LEAPIN_Theme_Mod::$default_leapin_sidebar_widget_title_type) {
            // tile
            $color = $inst->get(LEAPIN_IDs::$leapin_sidebar_widget_title_theme_color);
            $color = !empty($color) ? $color : '#252525';
            $css .= sprintf('.sidebar .widget-title{background-color: %s;}', $color);
            $css .= '.sidebar .widget-title::before{content: none;}';
        } elseif ($sidebar_widget_title_type == 'line') { // line
            $color = $inst->get(LEAPIN_IDs::$leapin_sidebar_widget_title_theme_color);
            $color = !empty($color) ? $color : '#828282';
            $css .= sprintf('.sidebar .widget-title::before, .sidebar .widget-title::after{border-top: %s 1px solid; background: none;transform:none;display: inline-block;}', $color);
            $css .= '.sidebar .widget-title::before{left: auto;}';
            $css .= '.sidebar .widget-title::after{right: auto;}';
        } else { // underline
            $color = $inst->get(LEAPIN_IDs::$leapin_sidebar_widget_title_theme_color);
            $color = !empty($color) ? $color : '#000';
            $css .= sprintf('.sidebar .widget-title{border-bottom: %s 3px solid;text-align: left;border-radius: 0; padding-left: 1rem; padding-bottom: 3px;}', $color);
            $css .= '.sidebar .widget-title::before{content: none;}';
        }
        return $css;
    }
}

$tpWidgets = new LEAPIN_Widgets();
?>
