/**
 * Page transition Module
 *
 * @type {{nextPage}}
 */
var LEAPIN_TRANS = (function ($) {

    var isAnimating = false,
        endCurrPage = false,
        endNextPage = false,
        animEndEventNames = {
            'WebkitAnimation': 'webkitAnimationEnd',
            'OAnimation': 'oAnimationEnd',
            'msAnimation': 'MSAnimationEnd',
            'animation': 'animationend'
        },
        // animation end event name
        animEndEventName = animEndEventNames[Modernizr.prefixed('animation')],
        // support css animations
        support = Modernizr.cssanimations;

    function nextPage(animation, barba, cb) {

        if (isAnimating) {
            return false;
        }

        isAnimating = true;
        var inClass;
        var outClass;
        var $currPage = $(barba.oldContainer);
        var $nextPage = $(barba.newContainer);
        var $header = $('header.header');
        // var barba_wrapper_height = $(window).height();
        // var container_height = barba_wrapper_height - $header.outerHeight() - $header.offset().top;

        // var barba_wrapper_height = document.getElementById('barba-wrapper').getBoundingClientRect().height;
        var barba_wrapper_height = $('#container').outerHeight() - $header.outerHeight();
        // if($('html.mobile-menu-left').length > 0){
        //     barba_wrapper_height = barba_wrapper_height * 0.93;
        // }
        var container_height = barba_wrapper_height;

        $('#barba-wrapper').css({'height': container_height, 'overflow': 'hidden'});

        $currPage.addClass('move-page');
        $nextPage.css({visibility: 'visible'});

        var transitions = LEAPIN_MODs.leapin_pjax_transition;
        var transitions_fallback = LEAPIN_MODs.leapin_pjax_transition_fallback;

        // if fallback transition is set
        if(isEdge() && !!transitions_fallback){
            transitions = transitions_fallback;
        }
        var transition = transitions[Math.floor(Math.random() * transitions.length)];
        inClass = transition['inClass'];
        outClass = transition['outClass'];

        $currPage.addClass(outClass).on(animEndEventName, function () {
            $currPage.off(animEndEventName);
            endCurrPage = true;
            if (endNextPage) {
                onEndAnimation($currPage, $nextPage, barba, cb);
            }
        });

        $nextPage.addClass(inClass).on(animEndEventName, function () {
            $nextPage.off(animEndEventName);
            endNextPage = true;
            if (endCurrPage) {
                onEndAnimation($currPage, $nextPage, barba, cb);
            }
        });

        if (!support) {
            onEndAnimation($currPage, $nextPage, barba, cb);
        }

    }

    function onEndAnimation($outpage, $inpage, barba, callback) {
        endCurrPage = false;
        endNextPage = false;
        isAnimating = false;
        barba.done();
        callback($outpage, $inpage, barba);
    }

    /**
     * Check if Edge Browser
     */
    function isEdge(){
        return window.navigator.userAgent.indexOf("Edge") > -1
    }

    return {nextPage: nextPage};

})(jQuery);