'use strict';

/**********************************
 * Main script file of Pjax blog
 * @since v1.0.0
 * @link https://leap-in.com
 * @author LeapIn Corp
 * */
var LEAPIN_CORE = (function ($, Barba, LP_MODs, LP_SCROLL, LP_TRANS) {

    var loader = '<div class="three-dots-spinner"><div class="bounce1"></div><div class="bounce2"></div><div class="bounce3"></div></div>';
    var x_scrolling_eles = [];
    var toggle_search_count = 0;
    var toc_highlight_clicked = false;
    var mobile_menu_open = false;
    var mobile_menu_direction, mobile_menu_position;
    var TOC_SELECTOR = '.sidebar .toc_widget a';
    var export_obj = {
        last_element_clicked: null,
        scroll_to_anker: scrollToAnker,
        is_pro: is_pro,
    };


    // DOM ready
    $(document)
        .ready(function () {
            leapin_onload(false);
        });

    /**
     * Called when on load and barba transition ends.
     *
     * @param call_from_barba
     */
    function leapin_onload(call_from_barba, barbaContainer) {
        // array for promise
        var p = [];

        // DOM ready
        check_browser_support();

        // set bg img
        set_bg_img();

        // check second nav existence
        style_adjust();

        // on load call
        if (!call_from_barba) {
            // disable hover effect while scrolling
            disable_hover_effect_while_scrolling();
            // stick header
            stick_header();
            // add click listener to search form in main header
            toggle_search_bar_in_head();
            // secondary nav slide transition
            slide_nav_underline();
            // mark current table of content
            markCurrentHeadline();
            // mobile menu init
            mobile_menu_init();

            if (is_pro()) {
                // lazy load
                LEAPIN_PRO.lazy_load_img();
                // scroll_trigger
                LEAPIN_PRO.scroll_trigger();
                // construct swipers
                LEAPIN_PRO.swiper_construct();

                // init swiper after main stylesheet loaded
                var si_count = 0, si_max_counts = 1000, si_interval = 100;
                var si = setInterval(function () {
                    if (LP_MODs.lp_style_loaded || ++si_count > si_max_counts / si_interval) {
                        LEAPIN_PRO.init_swiper();
                        clearInterval(si);
                    }
                }, si_interval);
            }

            // add nav loading
            $('#secondary-nav').append(loader);
            p.push(get_leapin_posts_ajax());
            p.push(get_leapin_nav_taxonomy_ajax());
            p.push(get_leapin_nav_thumbnail_ajax());
            p.push(get_leapin_nav_single_ajax());
            Promise.all(p).then(function () {
                // remove nav loading
                $('#secondary-nav').find('.three-dots-spinner').remove();
                if (is_pro()) {
                    // init swiper
                    LEAPIN_PRO.init_swiper(true);
                }
                // send view count
                if (is_bundle()) {
                    LEAPIN_BUNDLE.send_view_count(leapin_ajax);
                }
                // add horizontal scroll button
                x_scroll();
                // no barba call
                no_barba_els();
                // scroll animation
                scroll_to_hash();
                // add click event of more button
                regist_load_moreposts_click_listener();
                // mark class for nav structure
                mark_nav_class();
                // stick elements
                stick_sidebar();
                // set background images
                set_bg_img();
                // ripple button effect
                make_ripple_btn();
            });
        } else {
            // eval javascript in container
            leapin_eval(barbaContainer);
            // Call when barba(Pjax) transition done.
            get_leapin_posts_ajax().then(function () {
                // init swiper
                if (is_pro()) {
                    LEAPIN_PRO.init_swiper(true);
                }
                // no barba call
                no_barba_els();
                // add click event of more button
                regist_load_moreposts_click_listener();
                // set background images
                set_bg_img();
                // ripple button effect
                make_ripple_btn();
            });
        }
    }

    function is_pro() {
        if (typeof LEAPIN_PRO === 'object' && LP_MODs.leapin_is_pro) {
            return true;
        } else {
            return false;
        }
    }

    function is_bundle() {
        if (typeof LEAPIN_BUNDLE === 'object') {
            return true;
        } else {
            return false;
        }
    }

    /**
     * remove listners
     */
    function leapin_remove_listners() {
        var $ripples = $('.ripple');

        $ripples.each(function () {
            $(this).off('mousedown.ripple');
        });

        $ripples = null;

        // unregister eventlistner if it exists
        $(window).off('scroll.hidesidebar');

        var dontMoveLinks = '.nav a'; // (,) to register multiple selector
        // when clicked

        $('a[href^="#"]').not(dontMoveLinks).off('click.hashscroll');
        if (is_pro()) {
            $(TOC_SELECTOR).off('click.toc');
        }

        dontMoveLinks = null;

        LP_SCROLL.destroy();
    }

    /**
     * style adjustment
     */
    function style_adjust() {
        var $sec_nav = $('#secondary-nav');
        if ($sec_nav.find('li').length == 0) {
            $sec_nav.css('height', '0');
        }
        $sec_nav = null;
    }

    /**
     * is header transparent
     */
    function is_header_transparent() {
        return LP_MODs && LP_MODs.leapin_header_transparent && $('body.home').length > 0;
    }

    /**
     * Enable horizontal scroll of post cards widget
     *
     * @param $target
     */
    function x_scroll($target) {
        if (!$target) {
            $target = $('.post_cards.tile_ver3,.post_cards.tile_ver6');
        }

        $target.each(function (i, e) {
            var outerWidth = $(e).width();
            var innerLeft = $(e).find('li:last-child').position().left;
            var lastElewidth = $(e).find('li:last-child').width();
            var innerWidth = innerLeft + lastElewidth;
            var scrollRange = innerWidth - outerWidth;
            var pos = 0;

            var si = setInterval(function () {
                if (pos >= scrollRange || pos !== $(e).scrollLeft()) {
                    clearInterval(si);
                } else {
                    $(e).scrollLeft(pos + 1);
                    pos = $(e).scrollLeft();
                }
            }, 50);
            x_scrolling_eles.push(si);
        });
        $target = null;
    }

    /**
     * eval js in container
     */
    function leapin_eval(container) {
        var els = container ? container.querySelectorAll('script') : null;
        if (els !== null && els.length > 0 && LP_MODs.leapin_pjax_eval_script_in_container) {
            for (var i = 0, l = els.length; i < l; i++) {
                var el = els[i];
                if (el) {
                    eval(el.innerHTML);
                }
            }
        }
    }

    /**
     * remove transition
     */
    function disable_transition() {
        $('.swiper_ver1, .swiper_ver2, .swiper_ver3, .swiper_ver4')
            .addClass('no-transition')
            .find('.card__thumbnail, .card__header, .card__excerpt, .swiper-slide')
            .addClass('no-transition');
    }

    /**
     * Make header fixed
     */
    function stick_header() {
        var nav = '.main-header.fixed', timer;
        var $main_nav = $(nav);
        var main_top = 700;
        var oh = $("body").offset().top;
        if ($(window).width() > 600) {
            $main_nav.css('top', oh + 'px');
        }
        $(window).scroll(function () { //when window is scrolled
            var pos = main_top - $(window).scrollTop();
            clearTimeout(timer);

            timer = setTimeout(function () {
                if (pos > 0) {
                    $main_nav.removeClass('fadein');
                } else {
                    $main_nav.addClass('fadein');
                }
            }, 100, {passive: true});
        });
    }

    /**
     * Make sidebar fixed
     */
    function stick_sidebar() {

        if (LP_MODs && $(window).width() >= 1030) { // stick sns sidebar
            var main = "main", sns_sidebar = "#sns-sidebar";
            var sns_outer_top = $(main).position().top;
            var sns_outer_height = $(main).outerHeight();

            $(sns_sidebar).css('height', sns_outer_height);
            $(sns_sidebar).css('top', sns_outer_top);
            $(sns_sidebar + ' .sns-buttons').css('top', 150);
            $(sns_sidebar + ' .sns-buttons').addClass('ready');

            if (is_pro()) { // stick last element of sidebar widget
                // get header bottom position
                var $header_top = $("body").offset().top + $(".main-header.rel").outerHeight();

                // add gap
                $header_top += 10;
                $('.sidebar .widget:last-child').css('top', $header_top);
            }
        }
    }

    /**
     * disable hover effect while scrolling
     */
    function disable_hover_effect_while_scrolling() {
        var body = document.body,
            disable_hover_timer;

        window.addEventListener('scroll', function () {
            // disable hover
            clearTimeout(disable_hover_timer);
            if (!body.classList.contains('disable-hover')) {
                body.classList.add('disable-hover');
            }

            disable_hover_timer = setTimeout(function () {
                body.classList.remove('disable-hover');
            }, 100);
        }, {passive: true});
    }

    /**
     * Add animation to search bar in header
     */
    function toggle_search_bar_in_head() {
        var $searchform = $('.inner-header .searchform-container');
        var $nav = $('.primary-nav,.header-feature-button');
        var $label = $searchform.find('label');
        $label.click(function () {
            $searchform.toggleClass('expand');
            $nav.toggleClass('hide');
            if (++toggle_search_count > 1) {
                $nav.toggleClass('fadein');
            }
            if (!$searchform.hasClass('expand')) {
                $searchform.find('#search-input').blur();
            }
        });
    }

    /**
     * Deactivate Pjax transition of specific links
     */
    function no_barba_els() {
        // by selector
        if (LP_MODs.leapin_pjax_blacklist_selector) {
            $(LP_MODs.leapin_pjax_blacklist_selector).each(function () {
                $(this).addClass('no-barba');
            });
        }
    }


    /**
     * Add ripple animation effect
     */
    function make_ripple_btn() {
        var ripple, loc, cover, coversize, pos, x, y;

        var rippleEffect = function (e) {
            ripple = this;
            cover = document.createElement('span');
            coversize = ripple.offsetWidth;
            loc = ripple.getBoundingClientRect();
            x = e.pageX - loc.left - window.pageXOffset - (coversize / 2);
            y = e.pageY - loc.top - window.pageYOffset - (coversize / 2);
            pos = 'top:' + y + 'px; left:' + x + 'px; height:' + coversize + 'px; width:' + coversize + 'px;';

            // add ripple span
            ripple.appendChild(cover);
            cover.setAttribute('style', pos);
            cover.setAttribute('class', 'rp-effect');

            // remove added span
            setTimeout(function () {
                var list = document.getElementsByClassName("rp-effect");
                for (var j = list.length - 1; j >= 0; j--) {
                    list[j].parentNode.removeChild(list[j]);
                }
            }, 2000);
        };
        // get elements of ripple class
        var $ripples = $('.ripple');

        $ripples.each(function () {
            $(this).on('mousedown.ripple', rippleEffect);
        });

        $ripples = null;
    }

    /**
     * Add click listener to more posts buttons
     *
     * @param jQuery element $this
     */
    function regist_load_moreposts_click_listener($this) {
        var $more = $this ? $this.find('.ajax-more-posts') : $('.ajax-more-posts');

        $more.unbind("click").click(function () {
            var $target = $(this).closest('[data-ajax="leapin_posts"]');
            get_leapin_posts_ajax($target, true).then(function () {
                x_scroll($target.find('.tile_ver3,.tile_ver6'));

                var is_sidebar = $target.closest('.sidebar');
                if (is_sidebar.length > 0) {
                    stick_sidebar();
                }
            });
            return false;
        });
    }

    /**
     * Add classes to rich nav menu
     */
    function mark_nav_class() {
        $('ul.nav.rich.level-0 .level-1').each(function () {
            if ($(this).find('.level-2').length == 0) {
                $(this).addClass('without-level-2');
            } else {
                $(this).addClass('with-level-2');
            }
        });

        $('header nav:last-child').addClass('done');
    }

    /**
     * open / close mobile menu
     */
    function toggleMobileMenu(e) {

        // accelerator on
        $('#container').css({'will-change': 'transform, -webkit-filter, filter'});
        // init mobile menu background
        $('body').addClass('mobile-init');

        // set max height of mobile menu;
        var nav_max_height = "calc(100% - " + ($('.mobile-nav__header').outerHeight() + $('.mobile-nav__footer').outerHeight()) + "px)";
        $('.mobile-nav__nav').css('max-height', nav_max_height);

        requestAnimationFrame(function () {
            $('html').toggleClass('mobile-menu-left');
            $('.mobile-nav__button').toggleClass('open');
            if (mobile_menu_open) {
                // close
                setTimeout(function () {
                    $('#container').attr('style', '');
                }, 350);
            } else {
                // open
                $('#container').css({'height': '100vh', 'overflow': 'hidden'});
            }
            mobile_menu_open = !mobile_menu_open;
        });

        if(e){
            e.preventDefault();
            e.stopPropagation();
        }
    }

    /**
     * init mobile menu display
     */
    function mobile_menu_init() {
        var menu_level1 = '.mobile-nav > li.menu-item-has-children > a';
        var menu_level2 = '.mobile-nav > li.menu-item-has-children li.menu-item-has-children > a';

        // remove display: none property to init mobile menu
        $('.mobile-nav__cr').attr('style', '');

        // add  click action listner
        $('.mobile-nav__button, .mobile-nav__overlay').on('click', toggleMobileMenu);
        // add swipe action listner
        //横方向の座標を取得
        var getPosition = function(event) {
            return event.originalEvent.touches[0].pageX;
        }
        $('.mobile-nav__cr,.mobile-nav__overlay').on('touchstart', function(event) {
            mobile_menu_position = getPosition(event);
            mobile_menu_direction = ''; //reset
        });
        $('.mobile-nav__cr,.mobile-nav__overlay').on('touchmove', function(event) {
            if (mobile_menu_position - getPosition(event) > 20) { // left
                mobile_menu_direction = 'left'; // detect left swipe
            } else if (mobile_menu_position - getPosition(event) < -20){  // right
                mobile_menu_direction = 'right'; // detect right swipe
            }
        });
        $('.mobile-nav__cr,.mobile-nav__overlay').on('touchend', function(event) {
            if (mobile_menu_direction === 'left'){
                toggleMobileMenu();
            }
        }); // touch end


        $(menu_level1).on('click.level-1', function (e) {
            $(this).next('ul').slideToggle();
            if ($(this).attr('href') === "#") {
                e.preventDefault();
                e.stopPropagation();
            }
        });
        $(menu_level2).on('click.level-2', function (e) {
            $(menu_level1).off('click.level-1');
            $(this).next('ul').slideToggle();
            if ($(this).attr('href') === "#") {
                e.preventDefault();
                e.stopPropagation();
            }
            setTimeout(function () {
                $(menu_level1).on('click.level-1', function (ev) {
                    $(this).next('ul').slideToggle();
                    if ($(this).attr('href') === "#") {
                        ev.preventDefault();
                        ev.stopPropagation();
                    }
                });
            }, 300);
        });
    }

    /**
     * Set background image of elements by using data-src attributes
     */
    function set_bg_img() {
        $(".bg-img").each(function () {
            var $this = $(this);
            if ($this.data('src')) {
                $this.css('background-image', 'url(' + $this.data('src') + ')');
                $this.data('src', '');
            }
        });
    }

    /**
     * Get posts with ajax
     *
     * @param $leapin_posts         - posts container elements
     * @param clicked           - triggered by click event
     * @returns {Promise<any>}  - ajax call function
     */
    function get_leapin_posts_ajax($leapin_posts, clicked) {
        if (!clicked) {
            clicked = false;
        }
        return new Promise(function (resolve) {

            if (!$leapin_posts) {
                $leapin_posts = $('[data-ajax="leapin_posts"]');
            }
            if (!$leapin_posts.length) {
                return resolve();
            }
            var p = [];
            $leapin_posts.each(function (i, e) {
                var $this = $(e);
                if ($this.attr('data-ajax_on_load_call') == 1 || clicked) {
                } else {
                    // don't run
                    // continue
                    return true;
                }
                $this.attr('data-ajax_on_load_call', 0);
                var ready = function () {
                    var attr = $this.data();

                    // add loader
                    if (!clicked) {
                        $this.find('.post_cards_container').append(loader);
                    } else {
                        if (attr.layout_type !== 'tile_ver3'
                            && attr.layout_type !== 'tile_ver6') {
                            $this.find('.ajax-more-posts').before(loader);
                        }
                    }

                    var data = {
                        'action': 'leapin_ajax_call'
                    };
                    data.call_type = attr.ajax;
                    data.paged = $this.attr('data-paged');
                    for (var key in attr) {
                        if (key == 'ajax' || key == 'paged') continue;
                        data[key] = attr[key];
                    }
                    return data;
                };

                var callback = function (json) {
                    // remove loader
                    if ($this.attr('data-layout_type') === "swiper_ver1"
                        || $this.attr('data-layout_type') === "swiper_ver2"
                        || $this.attr('data-layout_type') === "swiper_ver3"
                        || $this.attr('data-layout_type') === "swiper_ver4"
                    ) {
                    } else {
                        if ($this.find('.three-dots-spinner').length > 0) {
                            $this.find('.three-dots-spinner').remove();
                        }
                    }

                    // append ajax response content
                    if ($this.attr('data-paged') == 0) {
                        $this.find('.post_cards_container').append(json['content']);
                    } else {
                        $this.find('ul').append(json.content);
                    }

                    $this.attr('data-paged', parseInt($this.attr('data-paged')) + 1);

                    if (!json.is_more_posts) {
                        $this.find('.ajax-more-posts').remove();
                    } else {
                        regist_load_moreposts_click_listener($this);
                    }
                };

                p.push(leapin_ajax(ready, callback));
            });
            Promise.all(p)
                .then(function () {
                    resolve();
                })
                .catch(function (err) {
                    console.log(err);
                });
        });
    }

    /**
     * Get thumbnails of sub menu items with ajax
     */
    function get_leapin_nav_thumbnail_ajax() {
        return new Promise(function (resolve) {
            // var p = [];
            var $thumbnails = $('[data-ajax="leapin_nav_thumbnail"]');
            if (!$thumbnails.length) {
                return resolve();
            }

            var ready = function () {
                var post_ids = "";
                $thumbnails.each(function () {
                    var post_type = $(this).data('object_type');
                    post_ids += String($(this).data(post_type)) + ",";
                });

                return {
                    'action': 'leapin_ajax_call',
                    'call_type': 'leapin_nav_thumbnail',
                    'post_ids': post_ids
                };
            };

            var callback = function (jsonData) {
                $thumbnails.each(function () {
                    var post_type = $(this).data('object_type');
                    var post_id = $(this).data(post_type);
                    var url = $(this).find('a').attr('href');
                    var thumbnail = jsonData[post_id] ? jsonData[post_id] : "";
                    $(this).prepend('<div class="img" style="background-image: url(' + thumbnail + ')"><a class="ripple" href="' + url + '"></a></div>');
                });
            };
            // p.push(leapin_ajax(ready, callback));
            leapin_ajax(ready, callback)
                .then(function () {
                    resolve();
                })
                .catch(function (err) {
                    console.log(err);
                });
        });
    }

    /**
     * Get posts of specific taxonomy with ajax, used only in Navigation
     *
     * @returns {Promise<any>}
     */
    function get_leapin_nav_taxonomy_ajax() {
        var p = [];
        return new Promise(function (resolve) {
            var $leapin_category = $('[data-ajax="leapin_nav_taxonomy"]');
            if (!$leapin_category.length) {
                return resolve();
            }

            $leapin_category.each(function (i, e) {
                var $this = $(e);
                var ready = function () {
                    var attr = $this.data();

                    var data = {
                        'action': 'leapin_ajax_call'
                    };
                    data['call_type'] = attr['ajax'];
                    data['taxonomy'] = attr['object_type'];
                    data['term_ids_or_slugs'] = attr[attr['object_type']];
                    data['posts_per_page'] = 4;
                    data['call_position'] = attr['call_position'];
                    return data;
                };
                var callback = function (json) {
                    $this.append(json['content']);
                    $this.addClass('menu-item-has-children');
                    $this.children('a').attr('href', '#');
                };

                p.push(leapin_ajax(ready, callback));
            });
            Promise.all(p)
                .then(function () {
                    resolve();
                })
                .catch(function (err) {
                    console.log(err);
                });
        });
    }

    /**
     * Get single post in Navigation with ajax
     *
     * @returns {Promise<any>}
     */
    function get_leapin_nav_single_ajax() {
        var p = [];
        return new Promise(function (resolve) {
            var $leapin_nav_singles = $('[data-ajax="leapin_nav_single"]');
            if (!$leapin_nav_singles.length) {
                return resolve();
            }

            $leapin_nav_singles.each(function (i, e) {
                var $this = $(e);
                var ready = function () {
                    var attr = $this.data();

                    var data = {
                        'action': 'leapin_ajax_call'
                    };
                    data['call_type'] = attr['ajax'];
                    data['post_type'] = attr['object_type'];
                    data['post_id'] = attr[attr['object_type']];
                    data['posts_per_page'] = 1;
                    data['call_position'] = attr['call_position'];
                    return data;
                };
                var callback = function (json) {
                    $this.append(json['content']);
                    $this.addClass('menu-item-has-children');
                    $this.children('a').attr('href', '#');
                };
                p.push(leapin_ajax(ready, callback));
            });
            Promise.all(p)
                .then(function () {
                    resolve();
                })
                .catch(function (err) {
                    console.log(err);
                });
        });
    }

    /**
     * Ajax main function
     *
     * @param ready
     * @param callback
     */
    function leapin_ajax(ready, callback) {
        return new Promise(function (resolve, reject) {
            leapin_ajax_ready(ready).then(function (data) {
                return leapin_ajax_call(data);

            }).then(function (json) {
                resolve(leapin_ajax_done(json, callback));

            }).catch(function (error) {
                reject(error + this);

            });
        });
    }

    /**
     * Ajax wrapper function
     *
     * @param data
     * @returns Promise
     */
    function leapin_ajax_call(data) {
        return new Promise(function (resolve, reject) {
            $.ajax({
                type: LP_MODs.ajax_post_type,
                url: LP_MODs.ajax_url,
                data: data,
                success: function (response) {
                    var jsonData = JSON.parse(response);
                    resolve(jsonData);

                },
                error: function (err) {
                    reject(err);

                }
            });
        });
    }

    /**
     * Ajax callback handling
     *
     * @param json
     * @param callback
     * @returns Promise
     */
    function leapin_ajax_done(json, callback) {
        return new Promise(function (resolve) {
            resolve(callback(json));
        });
    }

    /**
     * Ajax data passer
     *
     * @param ready
     * @returns Promise
     */
    function leapin_ajax_ready(ready) {
        return new Promise(function (resolve) {
            resolve(ready());
        });
    }

    /**
     * Pjax page load main function
     */
    document.addEventListener('DOMContentLoaded', function () {
        var ww = $(window).width();

        // popstate
        var popping = false;

        // listen popstate event
        window.addEventListener('popstate', function (e) {
            var hashLocation = location.hash;
            var hashSplit = hashLocation.split("#!/");
            var hashName = hashSplit[1];

            if (hashName !== '') {
                var hash = window.location.hash;
                if (hash === '') {
                    popping = e.path[0].location.href;
                }
            }
            export_obj.last_element_clicked = null;
        });

        if (LP_MODs.leapin_pjax_enable && ww >= parseInt(LP_MODs.leapin_pjax_min_window_size)) {
            /* init Pjax */
            Barba.Pjax.init();
            if (LP_MODs.leapin_pjax_prefetch_enable) {
                Barba.Prefetch.init();
            }
        }

        Barba.Pjax.originalPreventCheck = Barba.Pjax.preventCheck;
        /**
         * Custom Barba check
         * @param evt
         * @param element
         * @returns {boolean} - false: no barba
         *                    - true: barba transition
         */
        Barba.Pjax.originalPreventCheck = Barba.Pjax.preventCheck;
        Barba.Pjax.preventCheck = function (evt, element) {
            var ret = true;
            if (element) {
                var $el = $(element);

                if ($el.hasClass('no-barba')) {
                    return false;
                }
                // custom path check
                var ref = $el[0].pathname;
                if (LP_MODs.leapin_pjax_blacklist_path) {
                    $.each(LP_MODs.leapin_pjax_blacklist_path, function (i, e) {
                        /**
                         * {**} for wildcard
                         */
                        if (e.match(/\*\*/)) {
                            e = e.replace('**', '.+');
                            var regexp = new RegExp(e);
                            if (regexp.test(ref)) {
                                ret = false;
                            }
                        } else {
                            if (decodeURI(ref).replace(/\/$/, '') === e.replace(/\/$/, '')) {
                                ret = false;
                            }
                        }
                    });
                    if (!ret) {
                        return false;
                    }
                }

                var no_barba_extension = LP_MODs.leapin_pjax_disable_extension;
                // extension check
                $.each(no_barba_extension, function (i, pattern) {
                    // ends-with match
                    if ((ref.lastIndexOf(pattern) + pattern.length === ref.length) && (pattern.length <= ref.length)) {
                        $el.attr('target', '_blank');
                        ret = false;
                    }
                    if (!ret) {
                        return false;
                    }
                });

                // external domain
                var site_url = location.protocol + '//' + location.host;
                if (!element.href.startsWith(site_url)) {
                    element.setAttribute('target', '_blank');
                    return false;
                }

                // anchor in diff page
                var url = location.protocol + '//' + location.host + location.pathname;
                var extract_hash = element.href.replace(/#.*$/, "");
                // same domain
                if (element.href.startsWith(location.protocol + '//' + location.host)) {
                    // if hash value exists
                    if (element.href.indexOf('#') > -1) {

                        // different page
                        if (extract_hash !== url) {
                            return true;
                        }
                    }
                }

                if (!Barba.Pjax.originalPreventCheck(evt, element)) {
                    return false;
                }
            } else {
                // element is null
                return false;
            }
            return true;
        };

        var beforeLeave = function (e) {
            // fold secondary nav menu
            $('.secondary-nav ul.sub-menu.level-1').attr('style', '');

            // stop autoplay
            if (is_pro()) {
                LEAPIN_PRO.stop_swiper_autoplay();
            }

            // stop x scroll
            $.each(x_scrolling_eles, function (index, val) {
                clearInterval(val);
            });

            // remove transition
            disable_transition();
        };

        /* store clicked element */
        Barba.Dispatcher.on('linkClicked', function (el) {
            export_obj.last_element_clicked = el;
            beforeLeave(el);
        });

        /* refresh google tag manager */
        Barba.Dispatcher.on('initStateChange', function () {

            // destroy prev page DOM
            leapin_remove_listners();

            popping = false;

            var $container = $('.barba-container');
            var $wrapper = $('#barba-wrapper');
            // mark current barba-container
            if (is_seamless_transition(export_obj.last_element_clicked)) {
                $container.addClass('seamless');
            } else {
                $wrapper.addClass('perspect');
            }
            $container.addClass('moving');

            // send static data to google analytics
            if (is_bundle()) {
                LEAPIN_BUNDLE.send_google_analytics();
            }

        });

        /* change classes of body when transition done */
        Barba.Dispatcher.on('transitionCompleted', function (currentStatus, prevStatus) {
            // remove mark from barba-container
            $('.barba-container').attr('class', 'barba-container').attr('style', '');
            // stick elements
            stick_sidebar();
            // remove will-change css
            $('html,body').css('will-change', '');

            scroll_to_hash();
            // mark current table of content
            markCurrentHeadline();

            if (is_pro()) {
                // lazy load
                LEAPIN_PRO.lazy_load_img();
                // scroll_trigger
                LEAPIN_PRO.scroll_trigger();
                // construct swiper
                LEAPIN_PRO.swiper_construct();
                // init swiper
                LEAPIN_PRO.init_swiper();
            }
            // send view count
            if (is_bundle()) {
                LEAPIN_BUNDLE.send_view_count(leapin_ajax);
            }
            if ($(window).width() <= 768 && mobile_menu_open) {
                toggleMobileMenu();
            }
        });

        Barba.Dispatcher.on('newPageReady', function (currentStatus, oldStatus, barbaContainer, newPageRawHTML) {

            // change header tags
            var $newPageHtml = $('<html />')
                .html(
                    $.parseHTML(
                        newPageRawHTML.match(/<html[^>]*>([\s\S.]*)<\/html>/i)[0],
                        document,
                        true
                    )
                );

            var headTags = "";
            if (LP_MODs.leapin_pjax_replace_tags_in_head) {
                headTags = LP_MODs.leapin_pjax_replace_tags_in_head;
            }
            var ids_only_in_old_page = [];
            var ids_only_in_new_page = [];
            if (LP_MODs.leapin_load_minimum_scripts_on_each_page) {
                var script_identifier = "script[id],style[id]";
                if (LP_MODs.leapin_css_async_loading !== 'off') {
                    script_identifier = "script[id]";
                }
                var current_ids = $(script_identifier)
                    .map(function () {
                        return $(this).attr("id")
                    }).get();
                var new_ids = $newPageHtml.find(script_identifier)
                    .map(function () {
                        return $(this).attr("id")
                    }).get();

                var all_els = current_ids.concat(new_ids);
                all_els.forEach(function (item) {
                    if (current_ids.includes(item) && !new_ids.includes(item)) {
                        ids_only_in_old_page.push("#" + item);
                        // console.log(`detect script only contained in old page. : ${item}`);
                    } else if (!current_ids.includes(item) && new_ids.includes(item)) {
                        ids_only_in_new_page.push("#" + item);
                        // console.log(`detect script only contained in new page. : ${item}`);
                    }
                });
            }

            var headTagArry = headTags.split(",").map(function (element, index, array) {
                return element.trim().replace("script#", "#").replace("link#", "#").replace("style#", "#");
            });

            var mergeArry = ids_only_in_old_page.concat(ids_only_in_new_page);
            mergeArry = mergeArry.concat(headTagArry.filter(function (item) {
                return mergeArry.indexOf(item) < 0;
            }));
            $.each(mergeArry, function (index, value) {
                var name = value.trim();
                var $new_tag = $newPageHtml.find(name);
                var $current_html = $('html');
                var $old_tag = $current_html.find(name);
                var new_dependencies = $new_tag.data('leapin_dependencies');
                var old_dependencies = $old_tag.data('leapin_dependencies');

                // find element in new page
                if ($new_tag && $new_tag.length > 0) {
                    // find element in old page
                    if ($old_tag.length > 0) {
                        var dummy_id = "dummy-" + Math.floor(Math.random() * Math.floor(99999));
                        // create dummy location to replace tag.
                        var dummy = '<link id="' + dummy_id + '" />';
                        // find target tag location and add dummy tag after it
                        $old_tag.last().after(dummy);

                        if (value !== "style#siteorigin-panels-layouts-head") {
                            // remove target tag
                            remove_old_tag($old_tag, old_dependencies);
                        }
                        // add new tag after dummy tag
                        add_new_tag("#" + dummy_id, $new_tag, $newPageHtml, $current_html, new_dependencies);
                        // remove dummy tag
                        $current_html.find("#" + dummy_id).remove();
                    } else {
                        // could not find in old page
                        add_new_tag(false, $new_tag, $newPageHtml, $current_html, new_dependencies);

                    }

                } else {
                    // cannot find element in new page
                    // remove element
                    if (value !== "style#siteorigin-panels-layouts-head") {
                        // remove target tag
                        remove_old_tag($old_tag, old_dependencies);
                    }
                }
            });
            var $newPageBody = $('<body />')
                .html(
                    $.parseHTML(
                        newPageRawHTML.match(/<body[^>]*>([\s\S.]*)<\/body>/i)[0],
                        document,
                        true
                    )
                );

            // change out of barba container area
            var $body = $('body');

            // change site title
            $body.find('#logo-typo-header').after($newPageBody.find('#logo-typo-header'));
            $body.find('#logo-header .logo-typo').first().remove();

            // change header transparent
            $body.find('#inner-header').attr('class', $newPageBody.find('#inner-header').attr('class'));

            // change admin bar
            var newAdminBar = $newPageBody.find('#wpadminbar');
            var oldAdminBar = $body.find('#wpadminbar');
            if (newAdminBar.length > 0 && oldAdminBar.length > 0) {
                oldAdminBar.empty().append(newAdminBar.children());
            }

            // change body class
            var new_cls = newPageRawHTML.match(/<body.+?class="([^""]*)"/i)[1] + " mobile-init";
            $body.removeClass();
            $body.addClass(new_cls);

            // woocommerce
            if ($body.hasClass('woocommerce-no-js')) {
                $body.removeClass('woocommerce-no-js').addClass('woocommerce-js');
            }

            $newPageHtml.remove();
            $newPageBody.remove();

            // fire onload js scripts
            leapin_onload(true, barbaContainer);
        });

        /* pjax animation */
        var MovePage = Barba.BaseTransition.extend({
            start: function () {
                Promise
                    .all([this.newContainerLoading, scrollToAnker('goTop', 500)])
                    .then(this.movePages.bind(this));
            },

            movePages: function () {
                var callback = function ($outpage, $inpage, barba) {
                    $('#barba-wrapper').removeClass('perspect').attr('style', '');
                    if (!mobile_menu_open) {
                        $('#container').attr('style', '');
                    }
                };
                $('#container').css({'height': '100vh', 'overflow': 'hidden'});
                LP_TRANS.nextPage(get_pjax_transition_type(), this, callback);
            }
        });

        /**
         * Get Custom Barba Transition
         * @returns Object
         */
        var getCustomTranstion = function () {
            var transitionObj = MovePage;
            var transition = 'MovePage';

            // is not browser back or forward
            if (!popping) {
                // is blog post clicked
                if (is_seamless_transition(export_obj.last_element_clicked)) {
                    transitionObj = LEAPIN_PRO.seamless_from_post_list;
                    transition = 'SeamlessFromPostList';
                }
            }

            Barba.HistoryManager.currentStatus().custom_transition = transition;
            return transitionObj;
        };
        Barba.Pjax.getTransition = getCustomTranstion;
    });

    /**
     * Get Pjax transition Type
     */
    function get_pjax_transition_type() {
        var transition_type = $('.barba-container').data('pjax_transition');
        return parseInt(transition_type);
    }

    /**
     * is seamless transition on
     */
    function is_seamless_transition(lastElementClicked) {
        var $le = $(lastElementClicked);
        var $closest_cards = $le.closest('.post_cards');

        var is_blog_post =
            ($le.parent('.card__thumbnail').length > 0
                || $le.parent('.card__title').length > 0
                || $le.hasClass('card__more')
            ) && !(
                $closest_cards.hasClass('swiper_ver1')
                || $closest_cards.hasClass('swiper_ver4')
            );

        if (is_blog_post && LP_MODs.leapin_seamless_transition && is_pro()) {
            return true;
        }
        return false;
    }

    /**
     * remove old tag
     */
    function remove_old_tag($old_tag, dependencies) {

        if (dependencies) {
            // remove target tag
            if (dependencies === "before" || dependencies === "localize") {
                $old_tag.prev('script').remove();
            } else if (dependencies === "after") {
                $old_tag.next('script').remove();
            }
        }
        $old_tag.remove();

    }

    /**
     * add new tag
     */
    function add_new_tag(dummy_id, $new_tag, $newPageHtml, $current_html, dependencies) {
        // get dependencies of new tag, used for script tag.
        var $new_tag_dependencies = "";
        if (dependencies) {
            if (dependencies === "before" || dependencies === "localize") {
                $new_tag_dependencies = $new_tag.prev('script');
            } else if (dependencies === "after") {
                $new_tag_dependencies = $new_tag.next('script');
            }
        }
        // add main parts
        if (dummy_id) {
            $current_html.find(dummy_id).after($new_tag);
        } else {
            var $nearest_prev = $new_tag.prevAll('[id]:first');
            // var $nearest_next = $new_tag.nextAll('[id]:first');
            var prev_id = $nearest_prev.attr("id");
            // var next_id = $nearest_next.attr("id");
            var prev_dependencies = $nearest_prev.data('leapin_dependencies');
            // var next_dependencies = $nearest_next.data('leapin_dependencies');
            var $nearest_prev_in_current_html = $current_html.find("#" + prev_id);
            if ($nearest_prev && $nearest_prev_in_current_html.length > 0) {
                if (prev_dependencies && prev_dependencies === "after") {
                    $nearest_prev_in_current_html.next().after($new_tag);
                } else {
                    $nearest_prev_in_current_html.after($new_tag);
                }
            } else {
                $('head').append($new_tag);
            }
        }

        // add dependencies
        var new_tag_id = $new_tag.attr("id");
        if ($new_tag_dependencies && new_tag_id) {
            // remove target tag
            if (dependencies === "before" || dependencies === "localize") {
                $current_html.find("#" + new_tag_id).before($new_tag_dependencies);
            } else if (dependencies === "after") {
                $current_html.find("#" + new_tag_id).after($new_tag_dependencies);
            }
        }

    }

    /**
     * Underline transition
     */
    function slide_nav_underline() {
        var $nav = $(".secondary-nav > li"),
            $slideLine = $("#secondary-slide-line");

        $nav.hover(
            // Hover on
            function () {
                $slideLine.css({
                    "width": $(this).width(),
                    "left": $(this).position().left
                });
            },
            // Hover out
            function () {
                // Disapear
                $slideLine.width(0);
            }
        );
    }


    /**
     * scroll to # position
     */
    function scroll_to_hash() {
        // hash value of url
        var urlHash = location.hash;

        // if hash value exists
        if (urlHash) {
            // scroll
            scrollToAnker(urlHash, 300);

        }
        var dontScrollLinks = '.nav a, #mobile-menu-toggle'; // (,) to register multiple selector
        // var dontScrollLinks = ''; // (,) to register multiple selector
        $('a[href^="#"]').not(dontScrollLinks).on('click.hashscroll', function () {
            // get link in the page
            var href = $(this).attr("href");
            if (href && href === "#") {
                // deactivate link behaivor
                return false;
            }
            // do scroll
            scrollToAnker(href, 200);
        });

    }

    /**
     * Run scroll animation
     *
     * @param hash
     * @param duration
     * @param delay
     * @returns Promise
     */
    function scrollToAnker(hash, duration, delay) {
        var deferred = Barba.Utils.deferred()
            , position
            , nav_height = 0
            , dt = Number.isInteger(duration) ? parseInt(duration) : 400
            , dl = Number.isInteger(delay) ? parseInt(delay) : 0;

        if (hash && hash === 'goTop') {
            position = 0;
        } else {
            nav_height = $(".main-header.fixed").outerHeight() + 55;
            position = $(hash).offset().top - nav_height;
        }
        $('html,body').css('will-change', 'scroll-position');
        $('html,body').stop().delay(dl).animate(
            {scrollTop: position},
            {
                duration: dt,
                complete: function () {
                    deferred.resolve();
                }
            });
        return deferred.promise;
    }

    /**
     * Check browser support
     */
    function check_browser_support() {
        // IE 10 and older
        var $doc, $body;
        if (navigator.userAgent.indexOf("MSIE") >= 0) {
            $doc = '<p style="color: #000000">' + LP_MODs.old_browser_notification + '</p>';
            $body = $('body');
            $body.css('background-color', '#ffffff');
            $body.empty();
            $body.html($doc);
        }

        if (isAndroidDefaultBrowser()) {
            var loc = window.location.href;
            var intent = loc.replace(/^(https|http):\/\//, 'intent://');
            $doc = '<p style="color: #000000">' + LP_MODs.old_browser_notification + '<br>' +
                '<a href="' + intent + '#Intent;scheme=https;action=android.intent.action.VIEW;package=com.android.chrome;end">' + LP_MODs.message_open_with_chrome + '</a>' +
                '<br><a href="' + intent + '#Intent;scheme=https;action=android.intent.action.VIEW;package=org.mozilla.firefox;end">' + LP_MODs.message_open_with_firefox + '</a>' +
                '</p>';
            $body = $('body');
            $body.css('background-color', '#ffffff');
            $body.empty();
            $body.html($doc);
        }
    }

    /**
     * Judge if it's android default browser
     *
     * @returns {boolean}
     */
    function isAndroidDefaultBrowser() {
        var isAndroidBrowser = false;
        var ua = window.navigator.userAgent;
        if ((/Android/.test(ua) && /Linux; U;/.test(ua) && !/Chrome/.test(ua)) ||
            (/Android/.test(ua) && /Chrome/.test(ua) && /Version/.test(ua)) ||
            (/Android/.test(ua) && /Chrome/.test(ua) && /SamsungBrowser/.test(ua))) {
            isAndroidBrowser = true;
        }
        return isAndroidBrowser;
    }

    // add function to String prototype
    if (!String.prototype.startsWith) {
        String.prototype.startsWith = function (searchString, position) {
            position = position || 0;
            return this.indexOf(searchString, position) === position;
        };
    }

    /**
     * Change font color of table of contents sidebar
     */
    function markCurrentHeadline() {

        if ($(TOC_SELECTOR).length > 0) {
            var toc_els = document.querySelectorAll(TOC_SELECTOR);
            var anchors = [];
            $(TOC_SELECTOR).each(function (i, e) {
                var hash = e.hash;
                var grp = hash.match(/^#(\d.+)$/);
                if (grp) {
                    // escape ids starting with number
                    hash = '#\\003' + grp[1];
                }
                anchors.push(document.querySelector(hash));
            });

            var highlight_io = function (entries, observer) {

                if (toc_highlight_clicked) {
                    return;
                }

                var toc_headline;
                var entry;
                for (var i = entries.length - 1; i >= 0; i--) {

                    entry = entries[i];
                    if (entry.intersectionRatio > 0) {
                        for (var j = 0; j < toc_els.length; j++) {
                            toc_headline = toc_els[j];
                            if (entry && toc_headline.hash === "#" + entry.target.id) {
                                toc_headline.classList.add('current');
                            } else {
                                if (toc_headline.classList.length > 0) {
                                    toc_headline.classList.remove('current');
                                }
                            }
                        }
                    }
                }
            };
            // scroll_trigger
            LP_SCROLL.trigger('current-headline', anchors, highlight_io);
            $(TOC_SELECTOR).on('click.toc', function () {
                toc_highlight_clicked = true;
                setTimeout(function () {
                    toc_highlight_clicked = false;
                }, 210);
                $(TOC_SELECTOR).removeClass('current');
                $(this).addClass('current');
            });
        }
    }

    return export_obj;
}(jQuery, Barba, LEAPIN_MODs, LEAPIN_SCROLL, LEAPIN_TRANS));
